@@ -5,8 +5,9 @@ from hbshare.base.data_pro import hb_api
 import pandas as pd
 import time
 
-def fieldsCheckd(kwargs,supportFields: tuple):
-    fields = kwargs.get('fields') 
+
+def fieldsCheckd(kwargs, supportFields: tuple):
+    fields = kwargs.get('fields')
     if fields is None or len(fields) == 0:
         # 元组转list
         kwargs['fields'] = list(supportFields)
@@ -16,7 +17,7 @@ def fieldsCheckd(kwargs,supportFields: tuple):
             raise ValueError("field %s not supported" % field)
 
 
-def commonQuery(urlEnum, pause=0.01, timeout=10,**kwargs):
+def commonQuery(urlEnum, pause=0.01, timeout=10, **kwargs):
     '''
         通用Api调用方法
         :param urlEnum: 指定API枚举
@@ -32,7 +33,7 @@ def commonQuery(urlEnum, pause=0.01, timeout=10,**kwargs):
     if kwargs is None:
         kwargs = {}
     # 判断目标字段是否指定，没指定则使用接口支持字段
-    fieldsCheckd(kwargs,cfg.supportFields)
+    fieldsCheckd(kwargs, cfg.supportFields)
     api = hb_api(timeout=timeout)
     pages = 1
     page = 1
@@ -40,22 +41,24 @@ def commonQuery(urlEnum, pause=0.01, timeout=10,**kwargs):
     data = []
     while page <= pages:
         kwargs['page'] = page
-        kwargs['perPage']= perPage
+        kwargs['perPage'] = perPage
         try:
             # json传参
             post_data = cfg.parsePostData(kwargs)
             # url链接后拼接
             params = cfg.parseParams(kwargs)
         except KeyError as e:
-            raise RuntimeError("Use commonQuery(%s) failed,parameter %s not found" % (urlEnum,e.args[0]))
+            raise RuntimeError(
+                "Use commonQuery(%s) failed,parameter %s not found" % (urlEnum, e.args[0]))
 
-        org_js = api.query(cfg.getUrl(), method=cfg.method, params=params,post_data=post_data)
+        org_js = api.query(cfg.getUrl(), method=cfg.method,
+                           params=params, post_data=post_data)
         status_code = str(org_js['code'])
         if status_code != '0000':
             status = str(org_js['desc'])
             raise ValueError(status)
         if 'body' not in org_js:
-            status = "未查询到估值信息"
+            status = "未查询到数据"
             raise ValueError(status)
         body = org_js['body']
         if type(body) is list:
@@ -63,7 +66,7 @@ def commonQuery(urlEnum, pause=0.01, timeout=10,**kwargs):
             data += org_js['body']
             continue
         if 'records' in body and 'pages' in body:
-            # 总页数  
+            # 总页数
             pages = body['pages']
             # 页码加1
             page += 1
@@ -72,11 +75,18 @@ def commonQuery(urlEnum, pause=0.01, timeout=10,**kwargs):
             continue
         # 返回的是单个对象
         data.append(body)
-    prod_df = pd.DataFrame(data,columns = kwargs['fields'])
+    prod_df = pd.DataFrame(data, columns=kwargs['fields'])
     return prod_df
 
 
 if __name__ == '__main__':
 
-    data = commonQuery('SC_VALUATION_A', startDate ='2019-07-22 00:00:00', endDate='2019-07-22 00:00:00')
+    data = commonQuery('FOF_ZJJLIST', startDate='20220601', endDate='20220701',
+                       khdm="SSW281", jjdm='P40769', sorts=[
+                           {
+                               "field": "jzrq",
+                               "sort": "desc"
+                           }
+                       ], access_token='a1df4602e9044448ab79294875f15dbd',
+                       fields=['dataSource','sjly','jjdm','originalJjdm','jjmc','khdm', 'originalKhdm','khmc','jzrq'])
     print(data)
