@@ -45,8 +45,10 @@ class BL_Model:
             sql="""select zqdm,jyrq,pe,roe,gxl from bl_valuation where zqdm='{0}' and jyrq in ({1}) and jyrq<='20210930'"""\
                 .format(asset_name,','.join(trade_month))
             val_df2 =pd.read_sql(sql,con=db_engine.PrvFunDB().engine)
+            # val_df2.drop_duplicates(['zqdm', 'jyrq'], keep='last', inplace=True)
             val_df1=val_df1[val_df2.columns]
             val_df=pd.concat([val_df2,val_df1],axis=0).reset_index(drop=True)
+
         else:
             #load daata from local db since NASDAQ roe data is missed from hbdb and no w000083 data is available in the hbdb
             sql="""select zqdm,jyrq,pe,roe,gxl from bl_valuation where zqdm='{0}' and jyrq in ({1}) """\
@@ -178,8 +180,8 @@ class BL_Model:
         # sql="""select zqdm,zsz from st_market.t_st_zs_hq where zqdm in ({0}) and jyrq = '{1}' """\
         #     .format("'"+"','".join(asset_list)+"'",end_date)
         # val_df=self.hbdata.db2df(sql,db='alluser')
-        # weightdf=pd.merge(weightdf,self.hbdata.db2df(sql,db='alluser'),left_on='name',right_on='zqdm',how='left')
-        # weight_list=weightdf['mkr_value'].values.tolist()
+        # # weightdf=pd.merge(weightdf,self.hbdata.db2df(sql,db='alluser'),left_on='name',right_on='zqdm',how='left')
+        # # weight_list=weightdf['mkr_value'].values.tolist()
 
         return weight_list
 
@@ -306,12 +308,16 @@ class BL_Model:
     def update_valuation_data(self):
 
         local_file=pd.read_excel(r"E:\GitFolder\hbshare\fe\AAM\blmodel\PE_ROE_dividend.xlsx")
+        sql="delete from bl_valuation"
+        self.locdb.engine.execute(sql)
         local_file.to_sql('bl_valuation',con=self.locdb.engine,index=False,if_exists='append')
         print('valuation data updated successfully')
 
     def update_marketvalue_data(self):
 
         local_file=pd.read_excel(r"E:\GitFolder\hbshare\fe\AAM\blmodel\monthly MV.xlsx")
+        sql="delete from bl_market_value where Date='{}'".format(local_file['Date'][0])
+        self.locdb.engine.execute(sql)
         local_file.to_sql('bl_market_value',con=self.locdb.engine,index=False,if_exists='append')
         print('marketvalue_data updated successfully')
 
@@ -425,21 +431,16 @@ class BL_Model:
 if __name__ == '__main__':
 
 
-        end_date='20220131'
-        version='20220131_v1'
+        end_date='20220430'
+        version='20220430_v1'
         blm=BL_Model()
         localdb_engine=db_engine.PrvFunDB().engine
 
-        #blm.update_valuation_data()
-        #blm.update_asset_pool(r"E:\GitFolder\hbshare\fe\AAM\blmodel\asset_pool_update.xls", version)
+        blm.update_valuation_data()
+        # blm.update_asset_pool(r"E:\GitFolder\hbshare\fe\AAM\blmodel\asset_pool_update.xls", version)
         #blm.update_marketvalue_data()
 
 
-        # updates the market value table if necessary
-        # mkt_val=[]
-        # asset_list=[]
-        # blm.mkrvalue2db(asset_list,mkt_val,'20210827',db_engine.PrvFunDB().engine)
-
         #get the assets from pool
         sql=" select * from bl_assets_pool where version='{0}' ".format(version)
         assets_df=pd.read_sql(sql, con=localdb_engine)
