@@ -6,7 +6,7 @@ import statsmodels.api as sm
 import numpy as np
 from hbshare.fe.XZ import db_engine
 import plotly
-from scipy.optimize import shgo
+import plotly.io as pio
 import cvxopt.solvers as sol
 from cvxopt import matrix as mat
 sol.options['show_progress'] = False
@@ -193,8 +193,9 @@ class Untils:
         last_2years=(datetime.datetime.strptime(asofQ, '%Y%m%d')-datetime.timedelta(days=730))\
             .strftime('%Y%m%d')
 
-        sql="select min(jjdm) as jjdm from st_fund.t_st_gm_jjxx where cpfl='2' and (ejfl='13' or ejfl='35' or ejfl='37') and jjzt='0' and clrq<='{0}' group by jjmc ".format(last_2years)
-        stock_jjdm=hbdb.db2df(sql,db='funduser')
+        sql="select jjdm,jjmc,clrq  from st_fund.t_st_gm_jjxx where cpfl='2' and (ejfl='13' or ejfl='35' or ejfl='37') and jjzt='0' and clrq<='{0}'  ".format(last_2years)
+        stock_jjdm=hbdb.db2df(sql,db='funduser').sort_values(['clrq','jjdm'])
+        stock_jjdm.drop_duplicates(['jjmc'],keep='first',inplace=True)
 
         jjdm_list=stock_jjdm['jjdm'].tolist()
         ticker_con="'"+"','".join(jjdm_list)+"'"
@@ -250,29 +251,6 @@ class Untils:
 
         result = sol.qp(P, Q,G, h, A, b)
 
-        # num_x = np.shape(A1)[1]
-        #
-        # def my_func(x):
-        #     ls = 0.5 * (b1 - np.dot(A1, x)) ** 2
-        #     result = np.sum(ls)
-        #     return result
-        #
-        # def g1(x):
-        #     return np.sum(x)  # sum of X >= 0
-        #
-        # def g2(x):
-        #     return 1-np.sum(x)  # sum of X <= 1
-        #
-        # cons = ({'type': 'eq', 'fun': g2}
-        #         , {'type': 'ineq', 'fun': g1})
-        # x0 = np.zeros(num_x)
-        # bnds = [(0, 1)]
-        # for i in range(num_x - 1):
-        #     bnds.append((0, 1))
-        # res1 = shgo(my_func,
-        #             bounds=bnds,
-        #             constraints=cons)
-
         return [ x for x in result['x']]
 
 class Plot:
@@ -280,7 +258,10 @@ class Plot:
 
         self.fig_width=fig_width
         self.fig_height=fig_height
-
+        self.ams_color_lista=['#C94649','#EEB2B4','#E1777A','#D57C56','#E39A79','#DB8A66','#E5B88C']
+        self.ams_color_listb = ['#8588B7', '#B4B6D1', '#55598D', '#628497', '#A9C6CB','#866EA9','#B79BC7']
+        self.ams_color_listc = ['#7D7D7E', '#CACACA', '#A7A7A8', '#606063', '#C4C4C4','#99999B','#B7B7B7']
+    #
     def plot_render(self,data,layout, **kwargs):
         kwargs['output_type'] = 'div'
         plot_str = plotly.offline.plot({"data": data, "layout": layout}, **kwargs)
@@ -290,10 +271,17 @@ class Plot:
     #     fig = go.Figure(data=data, layout=layout)
     #     fig.show()
 
+    @staticmethod
+    def save_pic2local(data,layout,name):
+        fig = go.Figure(data=data, layout=layout)
+        fig.write_image(name+'.png')
+        # pio.write_image(fig,name+'.png')
+
+
     def plotly_style_bar(self,df, title_text,legend_x=0.30):
         fig_width, fig_height = self.fig_width,self.fig_height
         cols = df.columns.tolist()
-        # color_list = ['rgb(49, 130, 189)', 'rgb(204, 204, 204)', 'rgb(216, 0, 18)']
+
         data = []
         for i in range(len(cols)):
             col = cols[i]
@@ -301,7 +289,7 @@ class Plot:
                 x=df.index.tolist(),
                 y=df[col],
                 name=col,
-                # marker=dict(color=color_list[i])
+
             )
             data.append(trace)
 
@@ -316,11 +304,54 @@ class Plot:
 
         self.plot_render(data, layout)
 
+    def plotly_jjpic_bar(self,df, title_text,legend_x=0.30):
+        fig_width, fig_height = self.fig_width,self.fig_height
+        cols = df.columns.tolist()
+
+        a=int(np.floor(len(cols)/3))
+        b=len(cols)%3
+
+        color_list=self.ams_color_lista[0:a+int(b==1)]+\
+                   self.ams_color_listb[0:a+int(b==2)]+\
+                   self.ams_color_listc[0:a]
+
+        data = []
+        for i in range(len(cols)):
+            col = cols[i]
+            trace = go.Bar(
+                x=df.index.tolist(),
+                y=df[col],
+                name=col,
+                marker=dict(color=color_list[i])
+            )
+            data.append(trace)
+
+        layout = go.Layout(
+            title=dict(text=title_text),
+            autosize=False, width=fig_width, height=fig_height,
+            yaxis=dict(tickfont=dict(size=12), showgrid=True),
+            xaxis=dict(showgrid=True),
+            legend=dict(orientation="h", x=legend_x),
+            template='plotly_white'
+        )
+
+        self.plot_render(data, layout)
+        #self.save_pic2local(data, layout,title_text)
+
     def plotly_pie(self,df, title_text):
         fig_width, fig_height = self.fig_width,self.fig_height
         labels = df.index.tolist()
-        values = df.values.round(3).tolist()
-        data = [go.Pie(labels=labels, values=values, hoverinfo="label+percent",
+        values = df.values.round(3).reshape(1,len(df)).tolist()[0]
+
+        a=int(np.floor(len(labels)/3))
+        b=len(labels)%3
+
+        color_list=self.ams_color_lista[0:a+int(b==1)]+\
+                   self.ams_color_listb[0:a+int(b==2)]+\
+                   self.ams_color_listc[0:a]
+
+        # color_list = ['#C94649', '#8588B7', '#7D7D7E']
+        data = [go.Pie(labels=labels, values=values, hoverinfo="label+percent",marker=dict(colors=color_list),
                        texttemplate="%{label}: %{percent}")]
         layout = go.Layout(
             title=dict(text=title_text),
@@ -328,6 +359,7 @@ class Plot:
         )
 
         self.plot_render(data, layout)
+        #self.save_pic2local(data, layout, title_text)
 
     def plotly_area(self,df,title_text):
         fig_width, fig_height = self.fig_width,self.fig_height
