@@ -177,6 +177,108 @@ class FEDB:
         self.close_connection()
         return
 
+    def insert_hbs_rank_his_df(self, factor_df):
+        table_name = 'hbs_rank_his'
+        metadata = sqlalchemy.MetaData()
+        table = sqlalchemy.Table(
+            table_name, metadata,
+            sqlalchemy.Column('jjdm'),
+            sqlalchemy.Column('jsrq'),
+            sqlalchemy.Column('shift_ratio_size'),
+            sqlalchemy.Column('c_level_size'),
+            sqlalchemy.Column('shift_ratio_style'),
+            sqlalchemy.Column('c_level_style'),
+            sqlalchemy.Column('shift_ratio_theme'),
+            sqlalchemy.Column('c_level_theme'),
+            sqlalchemy.Column('shift_ratio_ind'),
+            sqlalchemy.Column('c_level_ind'),
+            sqlalchemy.Column('c_level_stock'),
+        )
+        metadata = self.create_metadata(metadata)
+        params = []
+        for idx in range(len(factor_df)):
+            rows = factor_df.iloc[idx]
+            param = dict()
+            param['jjdm'] = rows['jjdm']
+            param['jsrq'] = rows['jsrq']
+            param['shift_ratio_size'] = rows['shift_ratio_size']
+            param['c_level_size'] = rows['c_level_size']
+            param['shift_ratio_style'] = rows['shift_ratio_style']
+            param['c_level_style'] = rows['c_level_style']
+            param['shift_ratio_theme'] = rows['shift_ratio_theme']
+            param['c_level_theme'] = rows['c_level_theme']
+            param['shift_ratio_ind'] = rows['shift_ratio_ind']
+            param['c_level_ind'] = rows['c_level_ind']
+            param['c_level_stock'] = rows['c_level_stock']
+            params.append(param)
+            if len(params) > 1000:
+                self.update_data(table, params)
+                del params
+                params = []
+        if len(params) > 0:
+            self.update_data(table, params)
+        self.close_connection()
+        return
+
+    def insert_fund_index(self, factor_df):
+        table_name = 'fund_index'
+        metadata = sqlalchemy.MetaData()
+        table = sqlalchemy.Table(
+            table_name, metadata,
+            sqlalchemy.Column('TRADE_DATE'),
+            sqlalchemy.Column('INDEX_SYMBOL'),
+            sqlalchemy.Column('INDEX_NAME'),
+            sqlalchemy.Column('INDEX_POINT'),
+            sqlalchemy.Column('涨幅'),
+            sqlalchemy.Column('近1月涨幅'),
+            sqlalchemy.Column('近3月涨幅'),
+            sqlalchemy.Column('近6月涨幅'),
+            sqlalchemy.Column('近1年涨幅'),
+            sqlalchemy.Column('今年以来涨幅'),
+            sqlalchemy.Column('成立以来涨幅')
+        )
+        metadata = self.create_metadata(metadata)
+        params = []
+        for idx in range(len(factor_df)):
+            rows = factor_df.iloc[idx]
+            param = dict()
+            param['TRADE_DATE'] = rows['TRADE_DATE']
+            param['INDEX_SYMBOL'] = rows['INDEX_SYMBOL']
+            param['INDEX_NAME'] = rows['INDEX_NAME']
+            param['INDEX_POINT'] = rows['INDEX_POINT']
+            param['涨幅'] = rows['涨幅']
+            param['近1月涨幅'] = rows['近1月涨幅']
+            param['近3月涨幅'] = rows['近3月涨幅']
+            param['近6月涨幅'] = rows['近6月涨幅']
+            param['近1年涨幅'] = rows['近1年涨幅']
+            param['今年以来涨幅'] = rows['今年以来涨幅']
+            param['成立以来涨幅'] = rows['成立以来涨幅']
+            params.append(param)
+            if len(params) > 1000:
+                self.update_data(table, params)
+                del params
+                params = []
+        if len(params) > 0:
+            self.update_data(table, params)
+        self.close_connection()
+        return
+
+    def read_fund_index_latest_date(self):
+        sql = "SELECT max(TRADE_DATE) FROM fe_temp_data.fund_index GROUP BY INDEX_NAME"
+        df = self.get_df(sql)
+        latest_date = min(df['max(TRADE_DATE)'])
+        return latest_date
+
+    def read_fund_index_given_date(self, date):
+        sql = "SELECT TRADE_DATE, INDEX_SYMBOL, INDEX_NAME, INDEX_POINT FROM fe_temp_data.fund_index WHERE TRADE_DATE = '{0}'".format(date)
+        df = self.get_df(sql)
+        return df
+
+    def read_fund_index_gt_date(self, date):
+        sql = "SELECT TRADE_DATE, INDEX_SYMBOL, INDEX_NAME, INDEX_POINT FROM fe_temp_data.fund_index WHERE TRADE_DATE >= '{0}'".format(date)
+        df = self.get_df(sql)
+        return df
+
     def read_data(self, date, label_type):
         sql = "SELECT REPORT_DATE, REPORT_HISTORY_DATE, FUND_UNIVERSE, IS_ZC, LABEL_TYPE, LABEL_NAME, LABEL_VALUE, LABEL_VALUE_STRING FROM fe_temp_data.mutual_fund_holding_label where REPORT_DATE='{0}' AND LABEL_TYPE='{1}' AND FUND_UNIVERSE='FOCUS_MUTUAL_FUND_UNIVERSE' AND IS_ZC=1".format(date, label_type)
         df = self.get_df(sql)
@@ -185,15 +287,6 @@ class FEDB:
         df['IS_ZC'] = df['IS_ZC'].astype(int)
         return df
 
-    def read_hbs_theme_industry_property_given_code(self, code):
-        theme_list = ['大金融', '消费', '周期', '制造', 'TMT']
-        industry_list = ['电气设备', '商业贸易', '食品饮料', '采掘', '农林牧渔', '有色金属', '银行', '非银金融', '汽车', '建筑材料', '房地产', '钢铁', '建筑装饰', '公用事业', '医药生物', '家用电器', '电子', '通信', '轻工制造', '机械设备', '传媒', '化工', '计算机', '休闲服务', '交通运输', '纺织服装', '国防军工', '综合']
-        theme = ','.join(theme_list)
-        industry = ','.join(industry_list)
-        sql = "select jjdm, asofdate, ratio_theme, cen_theme, ratio_ind, cen_ind, industry_num, top5, {0}, {1} from fe_temp_data.hbs_industry_property where jjdm='{2}' and asofdate=(SELECT max(asofdate) FROM fe_temp_data.hbs_industry_property)".format(theme, industry, code)
-        df = self.get_df(sql)
-        return df
-
     def read_hbs_size_property_given_code(self, code):
         size_list = ['大盘', '中盘', '小盘']
         size = ','.join(size_list)
@@ -222,12 +315,82 @@ class FEDB:
         df = self.get_df(sql)
         return df
 
+    def read_hbs_size_style_property_history_given_code(self, code):
+        sql = "select jjdm, jsrq, shift_ratio_size, c_level_size, shift_ratio_style, c_level_style from fe_temp_data.hbs_cen_shift_ratio_his_style where jjdm='{0}'".format(code)
+        df = self.get_df(sql)
+        return df
+
+    def read_hbs_theme_industry_property_given_code(self, code):
+        sql = "select jjdm, asofdate, ratio_theme, cen_theme, ratio_theme_rank, cen_theme_rank, ratio_ind_1 as ratio_ind, cen_ind_1 as cen_ind, ratio_ind_1_rank as ratio_ind_rank, cen_ind_1_rank as cen_ind_rank, industry_num, top5 from fe_temp_data.hbs_industry_property_new where jjdm='{0}' and asofdate=(SELECT max(asofdate) FROM fe_temp_data.hbs_industry_property_new)".format(code)
+        df = self.get_df(sql)
+        return df
+
+    def read_hbs_theme_property_given_code(self, code):
+        theme_list = ['大金融', '消费', 'TMT', '制造', '周期']
+        theme = ','.join(theme_list)
+        sql = "select jjdm, asofdate, {0} from fe_temp_data.jjpic_theme_p where jjdm='{1}' and asofdate=(SELECT max(asofdate) FROM fe_temp_data.jjpic_theme_p)".format(theme, code)
+        df = self.get_df(sql)
+        return df
+
+    def read_hbs_industry_property_given_code(self, code):
+        sql = "select jjdm, asofdate, yjxymc, zsbl_mean, zsbl_med, zsbl_mean_rank, zsbl_med_rank from fe_temp_data.hbs_industry_property_1_industry_level where jjdm='{0}' and asofdate=(SELECT max(asofdate) FROM fe_temp_data.hbs_industry_property_1_industry_level)".format(code)
+        df = self.get_df(sql)
+        return df
+
+    def read_theme_exposure_given_code(self, code):
+        theme_list = ['大金融', '消费', 'TMT', '制造', '周期']
+        theme = ','.join(theme_list)
+        sql = "select jjdm, jsrq, {0} from fe_temp_data.hbs_theme_exp where jjdm='{1}'".format(theme, code)
+        df = self.get_df(sql)
+        return df
+
+    def read_industry_exposure_given_code(self, code):
+        sql = "select jjdm, jsrq, yjxymc, zjbl from fe_temp_data.hbs_industry_class1_exp where jjdm='{0}'".format(code)
+        df = self.get_df(sql)
+        return df
+
+    def read_hbs_theme_industry_property_history_given_code(self, code):
+        sql = "select jjdm, jsrq, shift_ratio_theme, c_level_theme, shift_ratio as shift_ratio_ind, c_level as c_level_ind from fe_temp_data.hbs_cen_shift_ratio_his_industry1 where jjdm={0}".format(code)
+        df = self.get_df(sql)
+        return df
+
     def read_hbs_holding_property_given_code(self, code):
         sql = "select jjdm, asofdate, 个股集中度 from fe_temp_data.hbs_holding_property where jjdm='{0}' and asofdate=(SELECT max(asofdate) FROM fe_temp_data.hbs_holding_property)".format(code)
         df = self.get_df(sql)
         return df
 
+    def read_hbs_holding_property_history_given_code(self, code):
+        sql = "select jjdm, jsrq, cenlv as c_level_stock from fe_temp_data.hbs_stock_cenlv_his where jjdm='{0}'".format(code)
+        df = self.get_df(sql)
+        return df
+
     def read_hbs_stock_trading_property_given_code(self, code):
         sql = "select * from fe_temp_data.hbs_stock_trading_property where jjdm='{0}' and asofdate=(SELECT max(asofdate) FROM fe_temp_data.hbs_stock_trading_property)".format(code)
         df = self.get_df(sql)
+        return df
+
+    def read_hbs_rank_history_given_code(self, code):
+        sql = "select jjdm, jsrq, shift_ratio_size, c_level_size, shift_ratio_style, c_level_style, shift_ratio_theme, c_level_theme, shift_ratio_ind, c_level_ind, c_level_stock from fe_temp_data.hbs_rank_his where jjdm='{0}'".format(code)
+        df = self.get_df(sql)
+        return df
+
+    def read_hbs_his_data(self, table_name):
+        sql = "select * from fe_temp_data.{0}".format(table_name)
+        df = self.get_df(sql)
+        return df
+
+    def read_industry_fundamental(self, sw_type):
+        sql = "select * from fe_temp_data.industry_fundamental where INDUSTRY_TYPE={0}".format(sw_type)
+        df = self.get_df(sql)
+        return df
+
+    def read_industry_valuation(self, sw_type):
+        sql = "select * from fe_temp_data.industry_valuation where INDUSTRY_TYPE={0}".format(sw_type)
+        df = self.get_df(sql)
+        return df
+
+    def read_industry_data(self, cols, table_name, sw_type):
+        cols = ','.join(cols)
+        sql = "select {0} from fe_temp_data.{1} where INDUSTRY_TYPE={2}".format(cols, table_name, sw_type)
+        df = self.get_df(sql)
         return df
\ No newline at end of file
