@@ -25,7 +25,7 @@ def ts_weight(data):
 def ts_pos(data, direction=1):
     data['POS'] = data['FACTORVALUE'] / data['FACTORVALUE'].abs() * direction
     data = data[~np.isnan(data['POS'])].reset_index(drop=True)
-    return data
+    return ts_weight(data)
 
 
 def xs_pos(data, direction=1, quantile=50):
@@ -36,7 +36,7 @@ def xs_pos(data, direction=1, quantile=50):
         lambda x: direction if x > quantile_p else (-direction if x < quantile_n else np.nan)
     )
     data = data[~np.isnan(data['POS'])].reset_index(drop=True)
-    return data
+    return xs_weight(data)
 
 
 def tsmom(start_date, direction=1, **kwargs):
@@ -77,9 +77,6 @@ def tsmom(start_date, direction=1, **kwargs):
         )
 
         data_t['FACTORVALUE'] = data_t['CLOSE'] / data_t['CLOSE0'] - 1
-        # data_t['POS'] = data_t['FACTORVALUE'] / data_t['FACTORVALUE'].abs() * direction
-        # data_t['POS'] = data_t['POS'].fillna(0)
-        data_t = ts_pos(data_t, direction=direction)
 
         data_tomorrow = data[np.array(data['TDATE'] == calendar[i + 1])]
 
@@ -92,8 +89,7 @@ def tsmom(start_date, direction=1, **kwargs):
 
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
-
-        data_t = ts_weight(data_t)
+        data_t = ts_pos(data_t, direction=direction)
 
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
@@ -138,8 +134,6 @@ def tswr(start_date, price_field='CLOSE', lag=1, **kwargs):
         )
         data_wr_range['FACTORVALUE'] = data_wr_range['WR1'] - data_wr_range['WR0']
 
-        data_wr_range = ts_pos(data=data_wr_range, direction=-1)
-
         data_t = data[
             np.array(data['TDATE'] == t_date)
             & np.array(data['VOL'] > kwargs['min_volume'])
@@ -162,12 +156,11 @@ def tswr(start_date, price_field='CLOSE', lag=1, **kwargs):
             data_tomorrow.rename(columns={price_field: 'CLOSE1'}),
             on='UCODE', how='left'
         )
-
         data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
-
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
-        data_t = ts_weight(data_t)
+
+        data_t = ts_pos(data=data_t, direction=-1)
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
     if len(positions) == 0:
@@ -220,13 +213,70 @@ def carry(start_date, **kwargs):
         # quantile_p = data_t['RY'].quantile(quantile / 100)
         # quantile_n = data_t['RY'].quantile(1 - quantile / 100)
         # data_t['POS'] = data_t['RY'].apply(lambda x: 1 if x > quantile_p else (-1 if x < quantile_n else 0))
+        data_t = pd.merge(
+            data_t, data_tomorrow[['UCODE', 'CLOSE']].rename(columns={'CLOSE': 'CLOSE1'}), on='UCODE', how='left'
+        )
+        data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
         data_t = xs_pos(data=data_t, quantile=quantile)
+        pos = data_t
+
+        pos['TDATE'] = calendar[i + 1]
+        pos['FACTOR'] = index_name
+
+        positions = pd.concat([positions, pos])
+        print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
+    if len(positions) == 0:
+        return
+
+    positions['WEIGHT'] = positions['WEIGHT'] * 100
+    positions['RETURN'] = positions['RETURN'] * 100
+    positions['FACTORVALUE'] = positions['FACTORVALUE'] * 100
+    return positions[
+        ['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', 'CLOSE', 'CLOSE1', 'POS', 'RETURN', 'FACTORVALUE', 'FACTOR', 'WEIGHT']
+    ].reset_index(drop=True)
+
+
+def tscarry(start_date, **kwargs):
+    data = kwargs['data']
+    liq_days = kwargs['liq_days']
+    data['UCODE'] = data['EXCHANGE'].apply(lambda x: str(x)) + data['PCODE'].apply(lambda x: str(x))
+    calendar = data['TDATE'].drop_duplicates().tolist()
+
+    window_days = kwargs['window_days']
+    index_name = 'tscarry_d' + str(window_days)
+
+    start_index = calendar.index(np.array(calendar)[np.array(calendar) >= start_date][0])
+
+    positions = pd.DataFrame()
+    for i in range(start_index, len(calendar) - 1):
+        t_date = calendar[i]
+        lookback_date = calendar[i - window_days]
+        data_ry = data[
+            np.array(data['TDATE'] <= t_date)
+            & np.array(data['TDATE'] > lookback_date)
+            ].groupby('UCODE').mean().reset_index()[['UCODE', 'RY']]
+        data_t = data[
+            np.array(data['TDATE'] == t_date)
+            & np.array(data['VOL'] > kwargs['min_volume'])
+            ]
+
+        data_liq = data[
+            data['TDATE'] == calendar[i - liq_days]
+            ][['UCODE']]
+
+        data_t = pd.merge(data_liq, data_t, on='UCODE', how='inner')
+
+        data_t = pd.merge(data_t.rename(columns={'RY': 'RY0'}), data_ry, on='UCODE')
+        data_t = data_t.rename(columns={'RY': 'FACTORVALUE'})
+        data_tomorrow = data[
+            np.array(data['TDATE'] == calendar[i + 1])
+        ]
 
         data_t = pd.merge(
             data_t, data_tomorrow[['UCODE', 'CLOSE']].rename(columns={'CLOSE': 'CLOSE1'}), on='UCODE', how='left'
         )
         data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
-        data_t = xs_weight(data_t)
+        data_t = ts_pos(data=data_t)
         pos = data_t
 
         pos['TDATE'] = calendar[i + 1]
@@ -319,10 +369,6 @@ def tsbasismom(start_date, **kwargs):
                                         data_t['return1'] - data_t['return2']
                                 ) * (data_t['LDATE2'] - data_t['LDATE1']).apply(lambda x: x.days)
 
-        # data_t['POS'] = data_t['FACTORVALUE'] / abs(data_t['FACTORVALUE'])
-        # data_t = data_t[~np.isnan(data_t['POS'])].reset_index(drop=True)
-        data_t = ts_pos(data_t)
-
         data_tomorrow = kwargs['data_raw'][
             np.array(kwargs['data_raw']['TDATE'] == calendar[i + 1])
         ]
@@ -331,7 +377,7 @@ def tsbasismom(start_date, **kwargs):
             data_t, data_tomorrow[['CCODE', 'CLOSE']].rename(columns={'CLOSE': 'CLOSE1'}), on='CCODE', how='left'
         )
         data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
-        data_t = ts_weight(data_t)
+        data_t = ts_pos(data_t)
         pos = data_t[
             ['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', 'CLOSE', 'POS', 'FACTORVALUE', 'CLOSE1', 'RETURN', 'WEIGHT']
         ].copy()
@@ -430,7 +476,6 @@ def xsbasismom(start_date, **kwargs):
 
         # data_t['POS'] = data_t['FACTORVALUE'] / abs(data_t['FACTORVALUE'])
         # data_t = data_t[~np.isnan(data_t['POS'])].reset_index(drop=True)
-        data_t = xs_pos(data_t, quantile=quantile)
 
         data_tomorrow = kwargs['data_raw'][
             np.array(kwargs['data_raw']['TDATE'] == calendar[i + 1])
@@ -440,7 +485,7 @@ def xsbasismom(start_date, **kwargs):
             data_t, data_tomorrow[['CCODE', 'CLOSE']].rename(columns={'CLOSE': 'CLOSE1'}), on='CCODE', how='left'
         )
         data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
-        data_t = xs_weight(data_t)
+        data_t = xs_pos(data_t, quantile=quantile)
         pos = data_t[
             ['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', 'CLOSE', 'POS', 'FACTORVALUE', 'CLOSE1', 'RETURN', 'WEIGHT']
         ].copy()
@@ -503,12 +548,11 @@ def xsmom(start_date, direction=1, **kwargs):
         )
         data_t['FACTORVALUE'] = data_t['CLOSE'] / data_t['CLOSE0'] - 1
 
-        data_t = xs_pos(data=data_t, direction=direction, quantile=quantile)
         data_t = pd.merge(
             data_t, data_tomorrow[['UCODE', 'CLOSE']].rename(columns={'CLOSE': 'CLOSE1'}), on='UCODE', how='left'
         )
         data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
-        data_t = xs_weight(data_t)
+        data_t = xs_pos(data=data_t, direction=direction, quantile=quantile)
         pos = data_t
 
         pos['TDATE'] = calendar[i + 1]
@@ -559,8 +603,6 @@ def xswr(start_date, price_field='CLOSE', lag=1, **kwargs):
             data_wr_range[data_wr_range['WR0'] > 0]['WR1'] / data_wr_range[data_wr_range['WR0'] > 0]['WR0'] - 1
         )
 
-        data_wr_range = xs_pos(data=data_wr_range, direction=-1, quantile=quantile)
-
         data_t = data[
             np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
             ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
@@ -587,7 +629,7 @@ def xswr(start_date, price_field='CLOSE', lag=1, **kwargs):
 
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
-        data_t = xs_weight(data_t)
+        data_t = xs_pos(data=data_t, direction=-1, quantile=quantile)
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
     if len(positions) == 0:
@@ -629,7 +671,6 @@ def mr(start_date, price_field='CLOSE', lag=1, **kwargs):
         data_mr_range['FACTORVALUE'] = data_mr_range['MR']
         # data_mr_range['POS'] = data_mr_range['FACTORVALUE'] / data_mr_range['FACTORVALUE'].abs()
         # data_mr_range['POS'] = data_mr_range['POS'].fillna(0)
-        data_mr_range = ts_pos(data=data_mr_range)
         data_t = data[
             np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
             ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
@@ -657,7 +698,7 @@ def mr(start_date, price_field='CLOSE', lag=1, **kwargs):
         # index_all.append(index_all[-1] * (1 + data_t['RETURN'].mean()))
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
-        data_t = ts_weight(data_t)
+        data_t = ts_pos(data=data_t)
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
     if len(positions) == 0:
@@ -699,7 +740,6 @@ def xsmr(start_date, price_field='CLOSE', lag=1, **kwargs):
 
         data_mr_range['FACTORVALUE'] = data_mr_range['MR']
 
-        data_mr_range = xs_pos(data=data_mr_range, quantile=quantile)
         data_t = data[
             np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
             ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
@@ -727,7 +767,7 @@ def xsmr(start_date, price_field='CLOSE', lag=1, **kwargs):
         # index_all.append(index_all[-1] * (1 + data_t['RETURN'].mean()))
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
-        data_t = xs_weight(data_t)
+        data_t = xs_pos(data=data_t, quantile=quantile)
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
     if len(positions) == 0:
@@ -774,7 +814,6 @@ def tsmr(start_date, price_field='CLOSE', lag=1, **kwargs):
         data_mr_range['FACTORVALUE'] = data_mr_range['MR1'] - data_mr_range['MR0']
         # data_mr_range['POS'] = data_mr_range['FACTORVALUE'] / data_mr_range['FACTORVALUE'].abs()
         # data_mr_range['POS'] = data_mr_range['POS'].fillna(0)
-        data_mr_range = ts_pos(data=data_mr_range)
 
         data_t = data[
             np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
@@ -803,7 +842,7 @@ def tsmr(start_date, price_field='CLOSE', lag=1, **kwargs):
         # index_all.append(index_all[-1] * (1 + data_t['RETURN'].mean()))
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
-        data_t = ts_weight(data_t)
+        data_t = ts_pos(data=data_t)
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
     if len(positions) == 0:
@@ -853,8 +892,6 @@ def xstsmr(start_date, price_field='CLOSE', lag=1, **kwargs):
                 data_mr_range[data_mr_range['MR0'] > 0]['MR1'] / data_mr_range[data_mr_range['MR0'] > 0]['MR0'] - 1
         )
 
-        data_mr_range = xs_pos(data=data_mr_range, quantile=quantile)
-
         data_t = data[
             np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
             ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
@@ -882,7 +919,7 @@ def xstsmr(start_date, price_field='CLOSE', lag=1, **kwargs):
         # index_all.append(index_all[-1] * (1 + data_t['RETURN'].mean()))
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
-        data_t = xs_weight(data_t)
+        data_t = xs_pos(data=data_t, quantile=quantile)
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
     if len(positions) == 0:
@@ -923,7 +960,6 @@ def mrchg(start_date, price_field='CLOSE', lag=1, **kwargs):
         data_mr_range['FACTORVALUE'] = data_mr_range['MRCHG']
         # data_mr_range['POS'] = data_mr_range['FACTORVALUE'] / data_mr_range['FACTORVALUE'].abs()
         # data_mr_range['POS'] = data_mr_range['POS'].fillna(0)
-        data_mr_range = ts_pos(data=data_mr_range)
 
         data_t = data[
             np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
@@ -952,7 +988,7 @@ def mrchg(start_date, price_field='CLOSE', lag=1, **kwargs):
         # index_all.append(index_all[-1] * (1 + data_t['RETURN'].mean()))
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
-        data_t = ts_weight(data_t)
+        data_t = ts_pos(data=data_t)
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
     if len(positions) == 0:
@@ -993,7 +1029,6 @@ def xsmrchg(start_date, price_field='CLOSE', lag=1, **kwargs):
 
         data_mr_range['FACTORVALUE'] = data_mr_range['MRCHG']
 
-        data_mr_range = xs_pos(data=data_mr_range, quantile=quantile)
 
         data_t = data[
             np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
@@ -1022,7 +1057,7 @@ def xsmrchg(start_date, price_field='CLOSE', lag=1, **kwargs):
         # index_all.append(index_all[-1] * (1 + data_t['RETURN'].mean()))
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
-        data_t = xs_weight(data_t)
+        data_t = xs_pos(data=data_t, quantile=quantile)
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
     if len(positions) == 0:
@@ -1074,7 +1109,6 @@ def tspoichg(start_date, **kwargs):
         )
 
         data_t['FACTORVALUE'] = data_t['POI'] / data_t['POI0'] - 1
-        data_t = ts_pos(data_t)
 
         data_tomorrow = data[np.array(data['TDATE'] == calendar[i + 1])]
 
@@ -1088,7 +1122,7 @@ def tspoichg(start_date, **kwargs):
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
 
-        data_t = ts_weight(data_t)
+        data_t = ts_pos(data_t)
 
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
@@ -1139,7 +1173,6 @@ def tspvolchg(start_date, **kwargs):
         )
 
         data_t['FACTORVALUE'] = data_t['PVOL'] / data_t['PVOL0'] - 1
-        data_t = ts_pos(data_t)
 
         data_tomorrow = data[np.array(data['TDATE'] == calendar[i + 1])]
 
@@ -1153,7 +1186,72 @@ def tspvolchg(start_date, **kwargs):
         data_t['TDATE'] = calendar[i + 1]
         data_t['FACTOR'] = index_name
 
-        data_t = ts_weight(data_t)
+        data_t = ts_pos(data_t)
+
+        positions = pd.concat([positions, data_t])
+        print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
+    if len(positions) == 0:
+        return
+    positions['WEIGHT'] = positions['WEIGHT'] * 100
+    positions['RETURN'] = positions['RETURN'] * 100
+    positions['FACTORVALUE'] = positions['FACTORVALUE'] * 100
+    return positions.drop(columns=['PVOL', 'PVOL0']).reset_index(drop=True)
+
+
+def xspvolchg(start_date, **kwargs):
+    data = kwargs['data']
+    liq_days = kwargs['liq_days']
+    data['UCODE'] = data['EXCHANGE'].apply(lambda x: str(x)) + data['PCODE'].apply(lambda x: str(x))
+    calendar = data['TDATE'].drop_duplicates().tolist()
+
+    window_days = kwargs['window_days']
+    quantile = kwargs['quantile']
+
+    index_name = 'xspvolchg_d' + str(window_days) + '_q' + str(quantile)
+
+    start_index = calendar.index(np.array(calendar)[np.array(calendar) >= start_date][0])
+
+    positions = pd.DataFrame()
+    for i in range(start_index, len(calendar) - 1):
+        t_date = calendar[i]
+        lookback_date = calendar[i - window_days]
+        data_t = data[
+            np.array(data['TDATE'] == t_date)
+            & np.array(data['VOL'] > kwargs['min_volume'])
+            ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', 'CLOSE', 'PVOL']]
+
+        data_liq = data[
+            data['TDATE'] == calendar[i - liq_days]
+            ][['UCODE']]
+
+        data_t = pd.merge(data_liq, data_t, on='UCODE', how='inner')
+
+        data_lookback = data[
+            np.array(data['TDATE'] == lookback_date)
+            & np.array(data['PVOL'] > 0)
+            ][['TDATE', 'UCODE', 'CLOSE', 'PVOL']]
+
+        data_t = pd.merge(
+            data_t[['EXCHANGE', 'PCODE', 'UCODE', 'CLOSE', 'PVOL']],
+            data_lookback[['UCODE', 'PVOL']].rename(columns={'PVOL': 'PVOL0'}),
+            on='UCODE', how='left'
+        )
+
+        data_t['FACTORVALUE'] = data_t['PVOL'] / data_t['PVOL0'] - 1
+
+        data_tomorrow = data[np.array(data['TDATE'] == calendar[i + 1])]
+
+        data_t = pd.merge(
+            data_t, data_tomorrow[['UCODE', 'CLOSE']].rename(columns={'CLOSE': 'CLOSE1'}),
+            on='UCODE', how='left'
+        )
+
+        data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
+
+        data_t['TDATE'] = calendar[i + 1]
+        data_t['FACTOR'] = index_name
+
+        data_t = xs_pos(data_t, quantile=quantile)
 
         positions = pd.concat([positions, data_t])
         print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
@@ -1207,14 +1305,12 @@ def xspoichg(start_date, **kwargs):
 
         data_t['FACTORVALUE'] = data_t['POI'] / data_t['POI0'] - 1
 
-        data_t = xs_pos(data=data_t, quantile=quantile)
-
         data_tomorrow = data[np.array(data['TDATE'] == calendar[i + 1])]
         data_t = pd.merge(
             data_t, data_tomorrow[['UCODE', 'CLOSE']].rename(columns={'CLOSE': 'CLOSE1'}), on='UCODE', how='left'
         )
         data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
-        data_t = xs_weight(data_t)
+        data_t = xs_pos(data=data_t, quantile=quantile)
         pos = data_t
 
         pos['TDATE'] = calendar[i + 1]
@@ -1264,14 +1360,133 @@ def xssigma(start_date, **kwargs):
             on='UCODE', how='inner'
         )
 
-        data_t = xs_pos(data=data_t, quantile=quantile)
-
         data_tomorrow = data[np.array(data['TDATE'] == calendar[i + 1])]
         data_t = pd.merge(
             data_t, data_tomorrow[['UCODE', 'CLOSE']].rename(columns={'CLOSE': 'CLOSE1'}), on='UCODE', how='left'
         )
         data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
-        data_t = xs_weight(data_t)
+        data_t = xs_pos(data=data_t, quantile=quantile)
+        pos = data_t
+
+        pos['TDATE'] = calendar[i + 1]
+        pos['FACTOR'] = index_name
+        positions = pd.concat([positions, pos])
+        print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
+    if len(positions) == 0:
+        return
+    positions['WEIGHT'] = positions['WEIGHT'] * 100
+    positions['RETURN'] = positions['RETURN'] * 100
+    positions['FACTORVALUE'] = positions['FACTORVALUE'] * 100
+    return positions.reset_index(drop=True)
+
+
+def xsskew(start_date, **kwargs):
+    data = kwargs['data']
+    liq_days = kwargs['liq_days']
+    data['UCODE'] = data['EXCHANGE'].apply(lambda x: str(x)) + data['PCODE'].apply(lambda x: str(x))
+    calendar = data['TDATE'].drop_duplicates().tolist()
+
+    window_days = kwargs['window_days']
+    quantile = kwargs['quantile']
+
+    index_name = 'xsskew_d' + str(window_days) + '_q' + str(quantile)
+
+    start_index = calendar.index(np.array(calendar)[np.array(calendar) >= start_date][0])
+
+    positions = pd.DataFrame()
+
+    for i in range(start_index, len(calendar) - 1):
+        t_date = calendar[i]
+        lookback_date = calendar[i - window_days]
+        data_t = data[
+            np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
+            ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', 'CLOSE']]
+        data_lookback = data[
+            np.array(data['TDATE'] >= lookback_date) & np.array(data['TDATE'] <= t_date)
+        ][['TDATE', 'UCODE', 'CLOSE']]
+        data_lookback_skew = data_lookback.pivot(index='TDATE', columns='UCODE', values='CLOSE').skew().reset_index()
+        data_tomorrow = data[
+            np.array(data['TDATE'] == calendar[i + 1])
+        ]
+
+        data_liq = data[
+            data['TDATE'] == calendar[i - liq_days]
+            ][['UCODE']]
+
+        data_t = pd.merge(data_liq, data_t, on='UCODE', how='inner')
+
+        data_t = pd.merge(
+            data_t[['EXCHANGE', 'PCODE', 'UCODE', 'CLOSE']],
+            data_lookback_skew[['UCODE', 0]].rename(columns={0: 'FACTORVALUE'}),
+            on='UCODE', how='left'
+        )
+        # data_t['FACTORVALUE'] = data_t['CLOSE'] / data_t['CLOSE0'] - 1
+
+        data_t = pd.merge(
+            data_t, data_tomorrow[['UCODE', 'CLOSE']].rename(columns={'CLOSE': 'CLOSE1'}), on='UCODE', how='left'
+        )
+        data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
+        data_t = xs_pos(data=data_t, quantile=quantile)
+        pos = data_t
+
+        pos['TDATE'] = calendar[i + 1]
+        pos['FACTOR'] = index_name
+        positions = pd.concat([positions, pos])
+        print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
+    if len(positions) == 0:
+        return
+    positions['WEIGHT'] = positions['WEIGHT'] * 100
+    positions['RETURN'] = positions['RETURN'] * 100
+    positions['FACTORVALUE'] = positions['FACTORVALUE'] * 100
+    return positions.reset_index(drop=True)
+
+
+def tsskew(start_date, **kwargs):
+    data = kwargs['data']
+    liq_days = kwargs['liq_days']
+    data['UCODE'] = data['EXCHANGE'].apply(lambda x: str(x)) + data['PCODE'].apply(lambda x: str(x))
+    calendar = data['TDATE'].drop_duplicates().tolist()
+
+    window_days = kwargs['window_days']
+
+    index_name = 'tsskew_d' + str(window_days)
+
+    start_index = calendar.index(np.array(calendar)[np.array(calendar) >= start_date][0])
+
+    positions = pd.DataFrame()
+
+    for i in range(start_index, len(calendar) - 1):
+        t_date = calendar[i]
+        lookback_date = calendar[i - window_days]
+        data_t = data[
+            np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
+            ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', 'CLOSE']]
+        data_lookback = data[
+            np.array(data['TDATE'] >= lookback_date) & np.array(data['TDATE'] <= t_date)
+            ][['TDATE', 'UCODE', 'CLOSE']]
+        data_lookback_skew = data_lookback.pivot(index='TDATE', columns='UCODE', values='CLOSE').skew().reset_index()
+        data_tomorrow = data[
+            np.array(data['TDATE'] == calendar[i + 1])
+        ]
+
+        data_liq = data[
+            data['TDATE'] == calendar[i - liq_days]
+            ][['UCODE']]
+
+        data_t = pd.merge(data_liq, data_t, on='UCODE', how='inner')
+
+        data_t = pd.merge(
+            data_t[['EXCHANGE', 'PCODE', 'UCODE', 'CLOSE']],
+            data_lookback_skew[['UCODE', 0]].rename(columns={0: 'FACTORVALUE'}),
+            on='UCODE', how='left'
+        )
+        # data_t['FACTORVALUE'] = data_t['CLOSE'] / data_t['CLOSE0'] - 1
+
+        data_t = pd.merge(
+            data_t, data_tomorrow[['UCODE', 'CLOSE']].rename(columns={'CLOSE': 'CLOSE1'}), on='UCODE', how='left'
+        )
+        data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1)
+        data_t = ts_pos(data=data_t)
         pos = data_t
 
         pos['TDATE'] = calendar[i + 1]
