@@ -9,7 +9,7 @@ if __name__ == '__main__':
     )
     from hbshare.quant.CChen.cta_factor.hsjy_func import hsjy_fut_index
     from hbshare.quant.CChen.cta_factor.factor_index import run
-    from hbshare.quant.CChen.cta_factor.factor_func import index_gen
+    from hbshare.quant.CChen.cta_factor.factor_func import index_gen, index_compose
     import hbshare as hbs
 
     hbs.set_token('830ca3e1998947f8a99ebb7f3e563623')
@@ -46,3 +46,7 @@ if __name__ == '__main__':
         sql_path=sql_write_path_work['daily'],
         sql_info=sql_user_work
     )
+    index_compose(
+        sql_path=sql_write_path_work['daily'],
+        sql_info=sql_user_work
+    )
