@@ -14,7 +14,7 @@ pymysql.install_as_MySQLdb()
 
 # 计算每只产品的年化收益，年华波动，夏普，最大回撤等指标
 def performance_analysis(
-        data_df, risk_free=0.015, start_date=datetime(2019, 1, 1).date(), end_date=datetime.now().date(),
+        data_df, risk_free=0.015, start_date=datetime(2010, 1, 1).date(), end_date=datetime.now().date(),
         ret_num_per_year=52, monthly_funds=None, print_info=True
 ):
     if monthly_funds is None:
@@ -30,7 +30,6 @@ def performance_analysis(
 
     result_all = pd.DataFrame()
     dd_all = data_df[[date_col]].copy()
-    ret_all = data_df[[date_col]].copy()
     for i in funds:
         single_df = data_df[[date_col, i]]
         # data_before = single_df[single_df[date_col] < start_date][date_col].tolist()
@@ -45,11 +44,11 @@ def performance_analysis(
         single_data = single_df[single_df[i] > 0]
         if len(single_data) > 1:
             if print_info:
-                print('\t计算 ' + i + ' 指标')
+                print('\t计算 ' + str(i) + ' 指标')
             start_index = single_data.index[0]
             single_df = single_df.iloc[start_index:].reset_index(drop=True)
 
-            # 剔除最新净值之后的空置（若产品最新净值未按时更新）
+            # 剔除最新净值之后的空值（若产品最新净值未按时更新）
             single_df = single_df[single_df[i] > 0].reset_index(drop=True)
 
             single_df['ret'] = single_df[i] / single_df[i].shift(1) - 1
@@ -163,15 +162,7 @@ def performance_analysis(
         else:
             dd_all[i] = None
 
-        # if len(ret_all) == 0:
-        #     ret_all = single_df[['t_date', 'ret']].rename(columns={'ret': i})
-        # else:
-        if 'ret' in single_df.columns:
-            ret_all = ret_all.merge(single_df[[date_col, 'ret']].rename(columns={'ret': i}), on=date_col, how='left')
-        else:
-            ret_all[i] = None
-
-    return result_all, dd_all, ret_all
+    return result_all, dd_all, data_df.set_index(date_col).pct_change().reset_index()
 
 
 def ret(data_df):
@@ -254,6 +245,7 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None, yearly_ret_
     ret_last_week = []
     ret_this_4 = []
     ret_this_8 = []
+    ret_3_months = []
     ret_6_months = []
     ret_2021 = []
     ret_2020 = []  # 年化
@@ -263,7 +255,7 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None, yearly_ret_
     yearly_return = {}
 
     for i in funds:
-        print('\t computing specific index: ' + i)
+        print('\t computing specific index: ' + str(i))
         single_df = data_df[[date_col, i]].copy()
         # single_df['ret'] = data_df[i] / data_df[i].shift(1)
         if i not in monthly_funds:
@@ -275,6 +267,11 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None, yearly_ret_
             except KeyError:
                 ret_this_8.append(None)
 
+            try:
+                ret_3_months.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 13] - 1)
+            except KeyError:
+                ret_3_months.append(None)
+
             try:
                 ret_6_months.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 25] - 1)
             except KeyError:
@@ -284,6 +281,7 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None, yearly_ret_
             ret_last_week.append(None)
             ret_this_4.append(None)
             ret_this_8.append(None)
+            ret_3_months.append(None)
             ret_6_months.append(None)
 
         single_df['year'] = single_df[date_col].apply(lambda x: x.year)
@@ -303,104 +301,6 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None, yearly_ret_
                 continue
             yearly_return[i][str(range_dates[t].year)] = yearly_data[-1] / yearly_data[0] - 1
 
-
-        # nav_2018 = single_df[
-        #     np.array(single_df[date_col] < datetime(2019, 1, 1).date())
-        #     & np.array(single_df[date_col] >= datetime(2017, 12, 29).date())
-        # ].reset_index(drop=True)
-        # nav_2018 = nav_2018[nav_2018[i] > 0].reset_index(drop=True)
-        #
-        # if len(nav_2018) > 0:
-        #     end_date_2018 = nav_2018[date_col].tolist()[-1]
-        # else:
-        #     end_date_2018 = datetime(2018, 12, 28).date()
-        # nav_2019 = single_df[
-        #     np.array(single_df[date_col] < datetime(2020, 1, 1).date())
-        #     & np.array(single_df[date_col] >= end_date_2018)
-        # ].reset_index(drop=True)
-        # nav_2019 = nav_2019[nav_2019[i] > 0].reset_index(drop=True)
-        #
-        # if len(nav_2019) > 0:
-        #     end_date_2019 = nav_2019[date_col].tolist()[-1]
-        # else:
-        #     end_date_2019 = datetime(2019, 12, 27).date()
-        # nav_2020 = single_df[
-        #     np.array(single_df[date_col] < datetime(2021, 1, 1).date())
-        #     & np.array(single_df[date_col] >= end_date_2019)
-        # ].reset_index(drop=True)
-        # nav_2020 = nav_2020[nav_2020[i] > 0].reset_index(drop=True)
-        #
-        # if len(nav_2020) > 0:
-        #     end_date_2020 = nav_2020[date_col].tolist()[-1]
-        # else:
-        #     end_date_2020 = datetime(2020, 12, 31).date()
-        # nav_2021 = single_df[
-        #     np.array(single_df[date_col] >= end_date_2020)
-        # ].reset_index(drop=True)
-        # nav_2021 = nav_2021[nav_2021[i] > 0].reset_index(drop=True)
-        #
-        # if len(nav_2018) > 1:
-        #     ret_2018.append(nav_2018[i].tolist()[-1] / nav_2018[nav_2018[i] > 0][i].tolist()[0] - 1)
-        # else:
-        #     ret_2018.append(None)
-        #
-        # if len(nav_2019) > 1:
-        #     ret_2019.append(nav_2019[i].tolist()[-1] / nav_2019[nav_2019[i] > 0][i].tolist()[0] - 1)
-        # else:
-        #     ret_2019.append(None)
-        #
-        # if len(nav_2020) > 1:
-        #     ret_2020.append(nav_2020[i].tolist()[-1] / nav_2020[nav_2020[i] > 0][i].tolist()[0] - 1)
-        # else:
-        #     ret_2020.append(None)
-        #
-        # if len(nav_2021) > 1:
-        #     ret_2021.append(nav_2021[i].tolist()[-1] / nav_2021[nav_2021[i] > 0][i].tolist()[0] - 1)
-        # else:
-        #     ret_2021.append(None)
-
-        # try:
-        #     ret_2021.append(
-        #         nav_2021[i].tolist()[-1] / nav_2021[nav_2021[i] > 0][i].tolist()[0] - 1
-        #     )
-        # except:
-        #     ret_2021.append(None)
-        #
-        # try:
-        #     fund_2020_days = nav_2020[date_col][len(nav_2020) - 1] - nav_2020[date_col][0]
-        #     ret_2020.append(
-        #         (nav_2020[i].tolist()[-1] / nav_2020[nav_2020[i] > 0][i].tolist()[0]) ** (365 / fund_2020_days.days) - 1
-        #     )
-        # except IndexError:
-        #     ret_2020.append(None)
-        #
-        # try:
-        #     fund_2019_days = nav_2019[date_col][len(nav_2019) - 1] - nav_2019[date_col][0]
-        #     if fund_2019_days.days < 90:
-        #         ret_2019.append(None)
-        #     else:
-        #         ret_2019.append(
-        #             (
-        #                     nav_2019[i].tolist()[-1] / nav_2019[nav_2019[i] > 0][i].tolist()[0]
-        #             ) ** (365 / fund_2019_days.days) - 1
-        #         )
-        # except:
-        #     ret_2019.append(None)
-        #
-        # if len(nav_2018) > 1:
-        #     fund_2018_days = nav_2018[date_col][len(nav_2018) - 1] - nav_2018[date_col][0]
-        #     # 运行超过半年才计算年化
-        #     if fund_2018_days.days < 90:
-        #         ret_2018.append(None)
-        #     else:
-        #         ret_2018.append(
-        #             (
-        #                     nav_2018[i].tolist()[-1] / nav_2018[nav_2018[i] > 0][i].tolist()[0]
-        #             ) ** (365 / fund_2018_days.days) - 1
-        #         )
-        # else:
-        #     ret_2018.append(None)
-
     if form:
         result_df = pd.DataFrame(
             {
@@ -408,6 +308,7 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None, yearly_ret_
                 '上周': ret_last_week,
                 '近四周': ret_this_4,
                 '近八周': ret_this_8,
+                '近三月': ret_3_months,
                 '近六月': ret_6_months,
                 # '2021': ret_2021,
                 # '2020': ret_2020,
@@ -431,7 +332,7 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None, yearly_ret_
 
 
 # 统计汇总
-def update_performance(start_d, end_d, funds, db_path, cal_db_path, month_release, data_type=''):
+def update_performance(start_d, end_d, funds, db_path, cal_db_path, month_release, data_type='', avg=True):
     fund_list = pd.read_sql_query(
         'select * from fund_list where `name` in ' + str(tuple(funds)), create_engine(db_path)
     )
