@@ -18,6 +18,7 @@ from hbshare.quant.CChen.cons import (
     wind_sec
 )
 from hbshare.quant.CChen.load_data import load_calendar_extra
+from hbshare.quant.CChen.cons import wind_sec
 import hbshare as hbs
 import pymysql
 import re
@@ -139,8 +140,8 @@ def wind_com_fut_sec_index(
         'select `code`, `name`, `t_date`, `close`, `product`, `volume`, `amount`, `oi_amount` from ' + table
         + ' where `t_date`<=' + end_date.strftime('%Y%m%d')
         + ' and `t_date`>=' + start_date.strftime('%Y%m%d')
-        + ' and `code` like \'%FI.WI\''
-        + ' and `product` in (\'index\') and `code`!=\'CCFI.WI\' order by `t_date`',
+        + ' and `code` in ' + str(tuple(wind_sec.keys()))
+        + ' and `code`!=\'CCFI.WI\' order by `t_date`',
         engine
     )
     data['code'] = data['code'].apply(lambda x: wind_sec[x])
