@@ -3,12 +3,15 @@
 import pandas as pd
 import numpy as np
 import pymysql
+import re
 from datetime import datetime
-from sqlalchemy import create_engine
+from hbshare.quant.CChen.stk import trade_calendar, load_index
+from hbshare.quant.CChen.cons import fut_sectors
 
 pymysql.install_as_MySQLdb()
 
 
+# 读取交易日日历
 def load_calendar(start_date=None, end_date=None, freq='', db_path='', table='stocks_index_ts'):
     if start_date is None:
         start_date = datetime(2010, 1, 1).date()
@@ -16,13 +19,27 @@ def load_calendar(start_date=None, end_date=None, freq='', db_path='', table='st
     if end_date is None:
         end_date = datetime.now().date()
 
-    engine_stocks = create_engine(db_path)
-    trade_cal = pd.read_sql_query(
-        'select distinct t_date from ' + table
-        + ' where t_date>=' + start_date.strftime('%Y%m%d') + ' and t_date<='
-        + end_date.strftime('%Y%m%d') + ' order by t_date',
-        engine_stocks
-    )
+    try:
+        # HB内部网络环境下优先读取内网数据
+        # print('Loading trade calendar from HB db')
+        trade_cal = trade_calendar(
+            start_date=start_date,
+            end_date=end_date
+        )
+        trade_cal = pd.DataFrame(
+            {
+                't_date': trade_cal
+            }, index=range(len(trade_cal))
+        )
+    except:
+        # HB内部网络连接失败情况下读取自建数据
+        # print('Failed to connect to HB db, trying loading trade calendar from local db')
+        trade_cal = pd.read_sql_query(
+            'select distinct t_date from ' + table
+            + ' where t_date>=' + start_date.strftime('%Y%m%d') + ' and t_date<='
+            + end_date.strftime('%Y%m%d') + ' order by t_date',
+            db_path
+        )
     if freq.lower() in ['w', 'week', 'weekly']:
         trade_cal = trade_cal.set_index(pd.to_datetime(trade_cal['t_date'])).resample('W').max().reset_index(drop=True)
     elif freq.lower() in ['m', 'month', 'monthly']:
@@ -55,7 +72,7 @@ def load_calendar_extra(start_date=None, end_date=None, freq='', db_path=''):
 # 输入产品列表，输出对应产品的周净值或月净值
 # 输入：DataFrame，输出：DataFrame
 # 如果first_date设置的太早会自动剔除前期空值
-# 净值第一次变化的时间点为数据起点（此条取消）
+# 需要自行建立对应格式的数据库以及存入对应数据！
 def load_funds_data(
         fund_list, first_date=None, end_date=None, freq='w', fillna=True, all_aligned=False,
         db_path='', cal_db_path='', print_info=False, drop_1=False,
@@ -80,7 +97,7 @@ def load_funds_data(
     fund_data_all = pd.read_sql_query(
         'select * from fund_data where ' + sql_l + ' and t_date<=' + end_date.strftime('%Y%m%d')
         + ' order by t_date',
-        create_engine(db_path)
+        db_path
     )[['t_date', 'nav', 'code']]
     fund_data_all['code'] = fund_data_all['code'].apply(lambda x: x.lower())
 
@@ -167,11 +184,73 @@ def load_funds_data(
     return cal_all[cal_all['t_date'] >= first_date].reset_index(drop=True)
 
 
+def load_funds_data1(
+        fund_list, first_date=None, end_date=None, freq='w', fillna=True,
+        db_path='', cal_db_path='', drop_1=False, print_info=False,
+):
+    if first_date is None:
+        first_date = datetime.now().date()
+
+    if end_date is None:
+        end_date = datetime.now().date()
+
+    cal = load_calendar(end_date=end_date, db_path=cal_db_path)
+    cal_spe = load_calendar_extra(freq=freq, end_date=end_date, db_path=cal_db_path)
+
+    if len(fund_list) == 1:
+        sql_l = 'code=\'' + fund_list['code'][0] + '\''
+    else:
+        sql_l = 'code in ' + str(tuple(fund_list['code']))
+
+    fund_data_all = pd.read_sql_query(
+        'select * from fund_data where ' + sql_l + ' and t_date<=' + end_date.strftime('%Y%m%d')
+        + ' order by t_date',
+        db_path
+    )[['t_date', 'nav', 'code']].drop_duplicates(subset=['t_date', 'code'])
+    fund_data_all['code'] = fund_data_all['code'].apply(
+        lambda x: fund_list[fund_list['code'] == str(x).upper()]['name'].tolist()[0]
+    )
+    fund_data = fund_data_all.pivot(index='t_date', columns='code', values='nav')
+    # 天眼赛能特殊处理
+    if '天眼赛能' in fund_data.columns:
+        fund_data.loc[:datetime(2019, 8, 2).date(), 'P22984'] = np.nan
+    fund_data = fund_data.reset_index()
+    fund_data = pd.merge(cal, fund_data, on='t_date', how='left').set_index('t_date')
+
+    if fillna:
+        if print_info:
+            print('空缺净值填充前值，最新净值之后不填充')
+        fund_data_is_na = fund_data.isna()
+        fund_data_is_na[fund_data_is_na] = np.nan
+        fund_data_is_na = fund_data_is_na.fillna(method='bfill').fillna(True)
+        fund_data = fund_data.fillna(method='ffill')
+        fund_data[fund_data_is_na] = np.nan
+
+    fund_data = pd.merge(cal_spe, fund_data, on='t_date', how='left')
+
+    if drop_1:
+        if print_info:
+            print('净值初期长期为1已去除')
+        fund_data = fund_data.set_index('t_date')
+        fund_data_bool = (fund_data.shift(-1) == fund_data) & (fund_data == 1)
+        fund_data[fund_data_bool] = np.nan
+        fund_data_is_na = fund_data.isna()
+        fund_data = fund_data.fillna(method='ffill')
+        fund_data[fund_data_is_na] = np.nan
+        fund_data = fund_data.reset_index()
+
+    i_date = fund_data.set_index('t_date').sum(axis=1)[fund_data.set_index('t_date').sum(axis=1) > 0].index[0]
+    if i_date > first_date:
+        first_date = i_date
+    cal_all = fund_data
+    return cal_all[cal_all['t_date'] >= first_date].reset_index(drop=True)
+
+
 # 输入产品列表，输出对应产品的周超额净值或月超额净值
 # 输入：DataFrame，输出：DataFrame
 # 输入的DataFrame中需要包含对应benchmark的code列
 # 如果first_date设置的太早会自动剔除前期空值
-# 指增产品只对净值大于1的序列进行计算，防止净值从1开始跳跃过大（此条取消）
+# 需要自行建立对应格式的数据库以及存入对应数据！
 def load_funds_alpha(
         fund_list, first_date=datetime.now().date(), end_date=datetime.now().date(), freq='w',
         fillna=True, all_aligned=False,
@@ -192,7 +271,7 @@ def load_funds_alpha(
     fund_data_all = pd.read_sql_query(
         'select * from fund_data where ' + sql_l + ' and t_date<=' + end_date.strftime('%Y%m%d')
         + ' order by t_date',
-        create_engine(db_path)
+        db_path
     )[['t_date', 'nav', 'code']]
     fund_data_all['code'] = fund_data_all['code'].apply(lambda x: x.lower())
 
@@ -218,12 +297,19 @@ def load_funds_alpha(
         if fund_code == 'P22984'.lower():
             fund_data = fund_data[fund_data['t_date'] >= datetime(2019, 8, 2).date()].reset_index(drop=True)
 
-        benchmark_data = pd.read_sql_query(
-            'select t_date, close from ' + index_table
-            + ' where t_date<=' + end_date.strftime('%Y%m%d')
-            + ' and code="' + benchmark + '" order by t_date',
-            create_engine(cal_db_path)
-        ).rename(columns={'close': 'bm'})
+        try:
+            benchmark_data = load_index(
+                index_list=[benchmark[:6]],
+                end_date=end_date
+            )[['TDATE', 'CLOSE']].rename(columns={'TDATE': 't_date', 'CLOSE': 'bm'})
+            benchmark_data['t_date'] = pd.to_datetime(benchmark_data['t_date']).dt.date
+        except:
+            benchmark_data = pd.read_sql_query(
+                'select t_date, close from ' + index_table
+                + ' where t_date<=' + end_date.strftime('%Y%m%d')
+                + ' and code="' + benchmark + '" order by t_date',
+                cal_db_path
+            ).rename(columns={'close': 'bm'})
 
         # fund_data = pd.merge(fund_data, benchmark_data, on='t_date', how='left')
 
@@ -310,8 +396,6 @@ def fund_pool_to_hb(fund_df, table='fund_pool', sql_path='', sql_ip='', sql_user
 
 # 跟踪池标的净值传入HBDB
 def fund_data_to_hb(path_local, path_hb, sql_hb, database, tables=None):
-    # engine_work = create_engine(sql_write_path_work['work'])
-    # engine_hb = create_engine(sql_write_path_hb['work'])
     key_name = 'id'
     if tables is None:
         tables = [
@@ -341,7 +425,7 @@ def fund_data_to_hb(path_local, path_hb, sql_hb, database, tables=None):
                 )
             else:
                 cursor.execute(
-                    'delete from ' + t + ' where `' + key_name + '`=' + str(list(id_hb_diff)[0])
+                    'delete from ' + t + ' where `' + key_name + '`=\'' + str(list(id_hb_diff)[0]) + '\''
                 )
             db_hb.commit()
             db_hb.close()
@@ -381,4 +465,31 @@ def fund_data_to_hb(path_local, path_hb, sql_hb, database, tables=None):
             print('\tnew data: ' + str(len(data_work_new)))
 
 
+def load_gzb(name, start_date, end_date, db_path, table='gzb', c_diff=True):
+    data = pd.read_sql_query(
+        'select 日期, 基金名称, 科目代码, 科目名称, 市值占净值 from ' + table
+        + ' where 日期<=' + end_date.strftime('%Y%m%d')
+        + ' and 日期>=' + start_date.strftime('%Y%m%d')
+        + ' and 基金名称="' + name + '"'
+        + ' and 市价 > 0 order by 日期, 科目名称',
+        db_path
+    )
+    data_info = data[['科目代码', '科目名称']].drop_duplicates(subset=['科目名称'])
+    if c_diff:
+        data = data.groupby(['日期', '科目名称'], as_index=False).sum()
+        data = data.merge(data_info, on='科目名称', how='left')
+    c_ind = data['科目代码'].str.split('310').str[0] == ''
+    data.loc[c_ind, '品种'] = data.loc[c_ind, '科目代码'].apply(lambda x: re.findall(r'[a-zA-Z]+', x[8:])[0].upper())
+    data['基金名称'] = name
+    sec_df = pd.DataFrame()
+    for i in fut_sectors:
+        sec = pd.DataFrame(fut_sectors[i]).rename(columns={0: '品种'})
+        sec['板块'] = i
+        sec_df = sec_df.append(sec)
+    data = data.merge(sec_df, on='品种', how='left')
+    data.loc[data['板块'].isnull().values == True, '板块'] = data.loc[data['板块'].isnull().values == True, '科目名称']
+    data['板块'] = data['板块'].apply(
+        lambda x: x.replace('私募证券投资基金', '').replace('私募投资基金', '').replace('私募基金', '')
+    )
+    return data
 
