@@ -6,7 +6,7 @@ import pandas as pd
 import numpy as np
 import pyecharts.options as opts
 from datetime import datetime, timedelta
-from pyecharts.charts import Line, Grid, Bar, Boxplot
+from pyecharts.charts import Line, Grid, Bar, Boxplot, Pie
 from pyecharts.globals import ThemeType
 from pyecharts.commons.utils import JsCode
 import pymysql
@@ -1594,3 +1594,244 @@ def market_win(start_date, end_date, freq='D', table='index_win', sql_path=sql_w
     )
 
     return web.overlap(index_r).overlap(c)
+
+
+def gzb_ts_positions(data, width=800, height=600):
+    data['绝对占比'] = data['市值占净值'].abs()
+    data_value = data.groupby(['日期'], as_index=False)['绝对占比'].sum().rename(columns={'绝对占比': '总比'})
+    data_value_by_sector = data.groupby(['日期', '板块'], as_index=False)['绝对占比'].sum()
+    data_value_by_sector = data_value_by_sector.merge(data_value, on='日期', how='left')
+    data_value_by_sector['相对占比'] = data_value_by_sector['绝对占比'] / data_value_by_sector['总比'] * 100
+
+    data_value_net_by_sector = data.groupby(['日期', '板块'], as_index=False)['市值占净值'].sum()
+
+    sectors = data['板块'].drop_duplicates().tolist()
+    web = Bar().add_xaxis(data_value['日期'].tolist())
+    web2 = Bar().add_xaxis(data_value['日期'].tolist())
+    web3 = Bar().add_xaxis(data_value['日期'].tolist())
+    for i in sectors:
+        abs_p = data_value_by_sector[data_value_net_by_sector['板块'] == i][['日期', '绝对占比']]
+        abs_p = data_value[['日期']].merge(abs_p, on='日期', how='left')
+
+        rel_p = data_value_by_sector[data_value_net_by_sector['板块'] == i][['日期', '相对占比']]
+        rel_p = data_value[['日期']].merge(rel_p, on='日期', how='left')
+
+        net_p = data_value_net_by_sector[data_value_net_by_sector['板块'] == i][['日期', '市值占净值']]
+        net_p = data_value[['日期']].merge(net_p, on='日期', how='left')
+
+        web.add_yaxis(
+            i,
+            abs_p['绝对占比'].round(2).tolist(),
+            stack='stack1',
+        )
+        web2.add_yaxis(
+            i,
+            rel_p['相对占比'].round(2).tolist(),
+            stack='stack2',
+        )
+        web3.add_yaxis(
+            i,
+            net_p['市值占净值'].round(2).tolist(),
+            stack='stack3',
+        )
+
+    web.set_series_opts(
+        label_opts=opts.LabelOpts(is_show=False)
+    ).set_global_opts(
+        legend_opts=opts.LegendOpts(is_show=False),
+        yaxis_opts=opts.AxisOpts(
+            name='总市值敞口',
+            axislabel_opts=opts.LabelOpts(formatter="{value} %"),
+            # min_='dataMin',
+            # max_='dataMax',
+        ),
+    )
+
+    web3.set_series_opts(
+        label_opts=opts.LabelOpts(is_show=False)
+    ).set_global_opts(
+        legend_opts=opts.LegendOpts(is_show=False),
+        yaxis_opts=opts.AxisOpts(
+            name='净市值敞口',
+            axislabel_opts=opts.LabelOpts(formatter="{value} %"),
+            min_='dataMin',
+            max_='dataMax',
+        ),
+    )
+
+    web2.set_series_opts(
+        label_opts=opts.LabelOpts(is_show=False)
+    ).set_global_opts(
+        title_opts=opts.TitleOpts(title=data['基金名称'][0] + " 持仓分布"),
+        legend_opts=opts.LegendOpts(
+            orient="vertical",
+            pos_top="5%",
+            # pos_left='2%',
+            pos_right='2%',
+            type_='scroll',
+        ),
+        yaxis_opts=opts.AxisOpts(
+            name='总市值占比',
+            axislabel_opts=opts.LabelOpts(formatter="{value} %"),
+            # min_='dataMin',
+            max_=100,
+        ),
+        datazoom_opts=[
+            opts.DataZoomOpts(xaxis_index=[0, 0], range_start=0, range_end=100),
+            opts.DataZoomOpts(xaxis_index=[0, 1], range_start=0, range_end=100, type_="inside"),
+            opts.DataZoomOpts(xaxis_index=[0, 2], range_start=0, range_end=100, type_="inside")
+        ],
+    )
+
+    grid = (
+        Grid(
+            init_opts=opts.InitOpts(
+                width=str(width) + "px",
+                height=str(height) + "px"
+            )
+        ).add(
+            web2,
+            grid_opts=opts.GridOpts(
+                pos_right="18%",
+                pos_left="8%",
+                pos_top="10%",
+                pos_bottom="60%"
+            ),
+            # is_control_axis_index=True
+        ).add(
+            web,
+            grid_opts=opts.GridOpts(
+                pos_right="18%",
+                pos_left="8%",
+                pos_top="50%",
+                pos_bottom="35%"
+            ),
+            # is_control_axis_index=True
+        ).add(
+            web3,
+            grid_opts=opts.GridOpts(
+                pos_right="18%",
+                pos_left="8%",
+                pos_top="75%",
+                # pos_bottom=""
+            ),
+            # is_control_axis_index=True
+        )
+    )
+
+    return grid
+
+
+def gzb_xs_position(data, width=800, height=600):
+    date = data['日期'][len(data) - 1]
+    name = data['基金名称'][0]
+    data = data[data['日期'] == date].reset_index(drop=True)
+    data['绝对占比'] = data['市值占净值'].abs()
+    data_value_by_sector = data.groupby(['板块'], as_index=False)['绝对占比'].sum().rename(
+        columns={'绝对占比': '板块市值占比'}
+    )
+    data = data.merge(data_value_by_sector, on='板块', how='left')
+    data = data.sort_values(by=['板块市值占比', '绝对占比'], ascending=False)
+    data['科目名称'] = data['科目名称'].apply(lambda x: x + ' 空' if data[data['科目名称'] == x]['市值占净值'].tolist()[0] < 0 else x)
+    inner_data = data[['板块', '板块市值占比']].drop_duplicates().reset_index(drop=True)
+    inner_data_pair = [
+        list(z) for z in zip(inner_data['板块'].tolist(), inner_data['板块市值占比'].round(2).tolist())
+    ]
+
+    outer_data = data[['科目名称', '绝对占比']].sort_values(by=['绝对占比'], ascending=False).reset_index(drop=True)
+    outer_data_pair = [
+        list(z) for z in zip(outer_data['科目名称'].tolist(), outer_data['绝对占比'].round(2).tolist())
+    ]
+
+    web = Pie(
+        init_opts=opts.InitOpts(
+            width=str(width) + "px",
+            height=str(height) + "px"
+        )
+    ).add(
+        series_name="板块占比",
+        data_pair=inner_data_pair,
+        radius=[0, "60%"],
+        center=["25%", "50%"],
+        label_opts=opts.LabelOpts(
+            position="inner",
+            # formatter="{a|{a}}{abg|}\n{hr|}\n {b|{b}: }{c}  {per|{d}%}  ",
+            # background_color="#eee",
+            # border_color="#aaa",
+            # border_width=1,
+            # border_radius=4,
+            # rich={
+            #     "a": {"color": "#999", "lineHeight": 22, "align": "center"},
+            #     "abg": {
+            #         "backgroundColor": "#e3e3e3",
+            #         "width": "100%",
+            #         "align": "right",
+            #         "height": 22,
+            #         "borderRadius": [4, 4, 0, 0],
+            #     },
+            #     "hr": {
+            #         "borderColor": "#aaa",
+            #         "width": "100%",
+            #         "borderWidth": 0.5,
+            #         "height": 0,
+            #     },
+            #     "b": {"fontSize": 12, "lineHeight": 33},
+            #     "per": {
+            #         "color": "#eee",
+            #         "backgroundColor": "#334455",
+            #         "padding": [2, 4],
+            #         "borderRadius": 2,
+            #     },
+            # },
+        )
+    ).add(
+        series_name="品种占比",
+        radius=[0, "30%"],
+        center=["75%", "50%"],
+        data_pair=outer_data_pair,
+        label_opts=opts.LabelOpts(
+            position="outside",
+            # formatter="{a|{a}}{abg|}\n{hr|}\n {b|{b}: }{c}  {per|{d}%}  ",
+            # background_color="#eee",
+            # border_color="#aaa",
+            # border_width=1,
+            # border_radius=4,
+            # rich={
+            #     "a": {"color": "#999", "lineHeight": 22, "align": "center"},
+            #     "abg": {
+            #         "backgroundColor": "#e3e3e3",
+            #         "width": "100%",
+            #         "align": "right",
+            #         "height": 22,
+            #         "borderRadius": [4, 4, 0, 0],
+            #     },
+            #     "hr": {
+            #         "borderColor": "#aaa",
+            #         "width": "100%",
+            #         "borderWidth": 0.5,
+            #         "height": 0,
+            #     },
+            #     "b": {"fontSize": 16, "lineHeight": 33},
+            #     "per": {
+            #         "color": "#eee",
+            #         "backgroundColor": "#334455",
+            #         "padding": [2, 4],
+            #         "borderRadius": 2,
+            #     },
+            # },
+        ),
+    ).set_global_opts(
+        title_opts=opts.TitleOpts(title=name + ' ' + date.strftime('%Y/%m/%d') + " 持仓分布"),
+        legend_opts=opts.LegendOpts(
+            is_show=False,
+            pos_left="left",
+            orient="vertical"
+        )
+    ).set_series_opts(
+        tooltip_opts=opts.TooltipOpts(
+            trigger="item", formatter="{a} <br/>{b}: {c} ({d}%)"
+        )
+    )
+
+    return web
+
