@@ -7,13 +7,15 @@ from hbshare.quant.CChen.weekly.xl_cons import (
 )
 import xlwings as xw
 import xlsxwriter as xl
+from datetime import datetime
+import pymysql
 
 
 class FundStats(object):
     note_str = {
-        'cta': '红底色：费后净值统计\n红字体：平均保证金高于30%',
-        'zx': '红底色：费后净值统计\n红字体：2020打新收益贡献年化5%以上',
-        'zz': '红字体：\n2020打新收益贡献年化5%以上',
+        'cta': '红底色：费后净值',
+        'zx': '红底色：费后净值\n红字体：2020打新贡献5%以上',
+        'zz': '红字体：2020打新贡献5%以上\n多头基于500算超额',
     }
     order_i = {
         '000300.SH': '沪深300',
@@ -41,8 +43,9 @@ class FundStats(object):
 
         self.long_only_stats = None
         self.key_years = 4
+        self.data_avg = pd.DataFrame()
 
-    def sheet_style0(self, sht, input_main, fund_dict, bold_list=None, red_list=None, skip_list=['多头']):
+    def sheet_style0(self, sht, input_main, nav_data, fund_dict, type1, bold_list=None, red_list=None, notes=None):
 
         row_n = self.row_num - 1
 
@@ -51,9 +54,61 @@ class FundStats(object):
         )
         input_main = input_main.set_index('index')
         for t in fund_dict:
-            if t in skip_list:
-                continue
-            input_data = input_main[fund_dict[t]].T
+            input_data = input_main[fund_dict[t]].T.copy()
+
+            # 计算分类平均
+            funds_list = fund_dict[t]
+            if '沪深300' in funds_list:
+                funds_list.pop(funds_list.index('沪深300'))
+            if '中证500' in funds_list:
+                funds_list.pop(funds_list.index('中证500'))
+            if '中证1000' in funds_list:
+                funds_list.pop(funds_list.index('中证1000'))
+            data_avg = nav_data[['t_date'] + funds_list].sort_values(by='t_date')
+            data_avg = data_avg[data_avg['t_date'] >= datetime(2017, 12, 27).date()].set_index('t_date').pct_change()
+            data_avg_nav = data_avg.mean(axis=1).fillna(0)
+            data_avg_nav = (data_avg_nav + 1).cumprod()
+
+            data_nav_df = data_avg_nav.reset_index().rename(columns={0: 'nav'})
+            data_nav_df['type2'] = t
+
+            data_nav_df['type1'] = type1
+            self.data_avg = self.data_avg.append(data_nav_df)
+
+            avg_date = data_avg_nav.reset_index().copy()
+            avg_date.loc[:, 'year'] = pd.to_datetime(avg_date['t_date']).dt.year
+            avg_date = avg_date.drop_duplicates(subset=['year'], keep='last')
+            avg_date = avg_date[avg_date['year'] >= 2018].sort_values(by='year', ascending=False).reset_index(drop=True)
+            avg_date.loc[:, 'year1'] = avg_date['year'].shift(1)
+            avg_date = avg_date[1:5].reset_index(drop=True)
+
+            result_key = []
+            for d in range(len(avg_date)):
+                rrr, _, _ = performance_analysis(data_avg_nav.reset_index(), start_date=avg_date['t_date'][d])
+                result_key.append(rrr)
+
+            result_key0, _, _ = performance_analysis(
+                data_avg_nav.reset_index(), start_date=data_avg_nav.index.tolist()[-52]
+            )
+
+            result_specific = performance_specific_ret(data_avg_nav.reset_index())
+
+            result_date = pd.DataFrame(
+                {
+                    '起始日期': None,
+                    '最新日期': data_avg_nav.index.tolist()[-1]
+                }, index=[0]
+            ).T.reset_index()
+
+            results_all = result_date.append(result_specific).append(result_key0)
+            for i in result_key:
+                results_all = results_all.append(i)
+
+            results_all = results_all.rename(columns={0: '平均'})
+            results_all['index'] = results_all['index'].apply(
+                lambda x: '累计收益率' if '以来累计' in x else ('年化收益率' if '以来年化' in x else x)
+            )
+            input_data = input_data.append(results_all.set_index('index').T)
             if self.sort:
                 input_data = input_data.sort_values(by=['本周', '上周', '最新日期', ], ascending=False)
             sht.range('B' + str(row_n + 1)).value = input_data
@@ -109,7 +164,7 @@ class FundStats(object):
                     (row_n, 3 + self.m1c + self.m2c * (1 + y)),
                     (row_n, 2 + self.m1c + self.m2c * (2 + y))
                 ).api.Merge()
-                sht.range((row_n, 3 + self.m1c + self.m2c * (1 + y))).value = input_data.columns[7 + y] + '以来'
+                sht.range((row_n, 3 + self.m1c + self.m2c * (1 + y))).value = input_data.columns[8 + y] + '以来'
                 sht.range(
                     (row_n, 3 + self.m1c + self.m2c * (1 + y)),
                     (row_n + 1 + len(input_data), 2 + self.m1c + self.m2c * (2 + y))
@@ -132,25 +187,31 @@ class FundStats(object):
                 ).api.NumberFormat = "0.00"
 
             for i in range(len(input_data)):
+                box = sht.range((row_n + 2 + i, 2))
+                # box.api.AddComment(Text='Current Sales')
+                if notes is not None:
+                    if input_data.index[i] in notes:
+                        note = notes[input_data.index[i]]['type']
+                        if note is not None:
+                            box.api.AddComment(Text=note)
                 if bold_list is not None:
                     if input_data.index[i] in bold_list:
-                        box = sht.range((row_n + 2 + i, 2))
                         box.api.Font.Color = 0x0000ff
                         box.api.Font.Bold = True
                 if red_list is not None:
                     if input_data.index[i] in red_list:
-                        box = sht.range((row_n + 2 + i, 2))
                         box.color = (192, 0, 0)
+
+                if input_data.index[i] == '平均':
+                    box.api.Font.Bold = True
             row_n += (len(input_data) + 2)
         print('Sheet 0 done')
 
     @staticmethod
-    def sheet_style1(sht, input_data, fund_dict, bold_list=None, red_list=None, skip_list=['多头']):
+    def sheet_style1(sht, input_data, fund_dict, bold_list=None, red_list=None):
         sht.range('A2').value = input_data
         col_num = 2
         for i in fund_dict:
-            if i in skip_list:
-                continue
             sht.range((1, col_num)).value = i
             sht.range((1, col_num), (1, col_num + len(fund_dict[i]) - 1)).api.Merge()
             sht.range((1, col_num), (1, col_num + len(fund_dict[i]) - 1)).api.HorizontalAlignment = -4108
@@ -220,8 +281,8 @@ class FundStats(object):
             order_all = order
             order = []
             for i in fund_dict:
-                if i == '多头':
-                    continue
+                # if i == '多头':
+                #     continue
                 order += fund_dict[i]
 
             data_o = data
@@ -267,16 +328,16 @@ class FundStats(object):
             sheet1.freeze_panes(1, 2)
             row_n = self.row_num
             for t in fund_dict:
-                if t == '多头':
-                    continue
-                rowl = len(fund_dict[t])
+                # if t == '多头':
+                #     continue
+                rowl = len(fund_dict[t]) + 1
                 for i in range(3, 3 + self.m1c + (1 + self.key_years) * self.m2c - 1):
                     col = ten2twentysix(i)
                     if i in list(np.array([5, 7, 8, 17, 19, 20]) + self.m1c):
                         sheet1.conditional_format(col + str(row_n + 1) + ':' + col + str(row_n + rowl), cell_format_r)
                     else:
                         sheet1.conditional_format(col + str(row_n + 1) + ':' + col + str(row_n + rowl), cell_format)
-                row_n += (len(fund_dict[t]) + 2)
+                row_n += (len(fund_dict[t]) + 2 + 1)
 
             sheet12 = wb_zz.add_worksheet('原始总览')
             sheet12.set_zoom(zoom=85)
@@ -292,14 +353,14 @@ class FundStats(object):
                         fund_dict_i[t] = fund_dict[t] + ['沪深300', '中证500', '中证1000']
                     else:
                         fund_dict_i[t] = fund_dict[t] + ['中证500']
-                rowl = len(fund_dict_i[t])
+                rowl = len(fund_dict_i[t]) + 1
                 for i in range(3, 3 + self.m1c + (1 + self.key_years) * self.m2c - 1):
                     col = ten2twentysix(i)
                     if i in list(np.array([5, 7, 8, 17, 19, 20]) + self.m1c):
                         sheet12.conditional_format(col + str(row_n + 1) + ':' + col + str(row_n + rowl), cell_format_r)
                     else:
                         sheet12.conditional_format(col + str(row_n + 1) + ':' + col + str(row_n + rowl), cell_format)
-                row_n += (len(fund_dict_i[t]) + 2)
+                row_n += (len(fund_dict_i[t]) + 2 + 1)
 
             wb_zz.add_worksheet('20年始超额净值')
             wb_zz.add_worksheet('19年始超额净值')
@@ -319,14 +380,14 @@ class FundStats(object):
             sheet1.freeze_panes(1, 2)
             row_n = self.row_num
             for t in fund_dict:
-                rowl = len(fund_dict[t])
+                rowl = len(fund_dict[t]) + 1
                 for i in range(3, 3 + self.m1c + (1 + self.key_years) * self.m2c - 1):
                     col = ten2twentysix(i)
                     if i in list(np.array([5, 7, 8, 17, 19, 20]) + self.m1c):
                         sheet1.conditional_format(col + str(row_n + 1) + ':' + col + str(row_n + rowl), cell_format_r)
                     else:
                         sheet1.conditional_format(col + str(row_n + 1) + ':' + col + str(row_n + rowl), cell_format)
-                row_n += (len(fund_dict[t]) + 2)
+                row_n += (len(fund_dict[t]) + 2 + 1)
 
             wb.add_worksheet('20年始净值')
             wb.add_worksheet('19年始净值')
@@ -350,9 +411,12 @@ class FundStats(object):
         self.sheet_style0(
             sht=sht1,
             input_main=data['main'],
+            nav_data=data['nav'],
+            type1=fund_type,
             fund_dict=fund_dict,
             bold_list=list_bold,
-            red_list=list_red
+            red_list=list_red,
+            notes=fund_list[['name', 'type']].set_index('name').T.to_dict()
         )
 
         sht2 = xlsx.sheets('20年始净值' if fund_type.lower() != 'zz' else '20年始超额净值')
@@ -410,10 +474,12 @@ class FundStats(object):
             self.sheet_style0(
                 sht=sht12,
                 input_main=data_o['main'],
+                nav_data=data_o['nav'],
+                type1=fund_type,
                 fund_dict=fund_dict_i,
                 bold_list=list_bold,
                 red_list=list(self.order_i.values()),
-                skip_list=[]
+                notes=fund_list[['name', 'type']].set_index('name').T.to_dict()
             )
 
             sht13 = xlsx.sheets('原始净值')
@@ -424,7 +490,6 @@ class FundStats(object):
                 fund_dict=fund_dict,
                 bold_list=list_bold,
                 red_list=list(self.order_i.values()),
-                skip_list=[]
             )
 
             sht14 = xlsx.sheets('原始动态回撤')
@@ -435,7 +500,6 @@ class FundStats(object):
                 fund_dict=fund_dict,
                 bold_list=list_bold,
                 red_list=list(self.order_i.values()),
-                skip_list=[]
             )
 
             self.long_only_stats = data_o['main'][
@@ -450,7 +514,6 @@ class FundStats(object):
                 fund_dict=fund_dict,
                 bold_list=list_bold,
                 red_list=list(self.order_i.values()),
-                skip_list=[]
             )
 
         xlsx.save()
@@ -462,8 +525,8 @@ class FundStats(object):
                 data_df=data['main'][
                     ['index'] + list(
                         set(
-                            fund_dict['长周期']
-                            + fund_dict['长周期（高波动）']
+                            fund_dict['中长周期']
+                            + fund_dict['中长周期（高波动）']
                             + fund_dict['短周期']
                             + fund_dict['短周期（高波动）']
                             + fund_dict['混合']
@@ -555,10 +618,10 @@ class FundStats(object):
             \n附件是量化产品跟踪表，净值更新截止至'''
             + self.end_date.strftime('%m/%d')
             + '''，产品净值走势图将另外更新在'''
-            '''\n\tCTA：http://fdc.intelnal.howbuy.com/zeppelin/#/notebook/2G2Q7YJKV'''
-            '''\n\t中性：http://fdc.intelnal.howbuy.com/zeppelin/#/notebook/2G75FWDDQ'''
-            '''\n\t指增：http://fdc.intelnal.howbuy.com/zeppelin/#/notebook/2G5HM79V7'''
-            '''\n\t指增α：http://fdc.intelnal.howbuy.com/zeppelin/#/notebook/2G5AB9NA2'''
+            '''\n\tCTA：http://quant.intelnal.howbuy.com/#/notebook/2G2Q7YJKV'''
+            '''\n\t中性：http://quant.intelnal.howbuy.com/#/notebook/2G75FWDDQ'''
+            '''\n\t指增：http://quant.intelnal.howbuy.com/#/notebook/2G5HM79V7'''
+            '''\n\t指增α：http://quant.intelnal.howbuy.com/#/notebook/2G5AB9NA2'''
             '''\n\t打开后若显示空白请点击Notebook->研究下其他文件，再点回跟踪产品净值可正常显示。'''
             '''\n\nCTA：'''
             '''\n\t上周(''' + self.end_date.strftime('%m/%d') + ''')产品'''
@@ -682,5 +745,28 @@ class FundStats(object):
         for i in range(len(r_dt)):
             print('\t' + r_dt.index[i] + '：' + str(round(r_dt[i] * 100, 2)) + '%')
 
+    def avg_to_hb(self, sql_path, table, db, sql_ip, sql_user, sql_pass):
+        sql_l = '''
+        (
+        id bigint not null AUTO_INCREMENT,
+        t_date  date,
+        type1  varchar(100),
+        type2  varchar(100),
+        nav float,
+        primary key (id)
+        )
+        '''
+        db = pymysql.connect(host=sql_ip, user=sql_user, password=sql_pass, database=db)
+        cursor = db.cursor()
+
+        sql = 'create table if not exists `' + table + '` ' + sql_l + ' comment=\'量化产品跟踪池\''
+        cursor.execute(sql)
+        print(table + ' generated')
+
+        cursor.execute('truncate table ' + table)
+        print('Clear ' + table)
+        db.close()
+        self.data_avg.to_sql(table, sql_path, if_exists='append', index=False)
+
 
 
