@@ -20,7 +20,7 @@ from hbshare.quant.Kevin.asset_allocation.macro_index.treasury_yield import Trea
 from hbshare.quant.Kevin.asset_allocation.macro_index.bond_trading import BondTrading
 from hbshare.quant.Kevin.asset_allocation.macro_index.future_data import FutureMarketIndex, FuturePrice
 from hbshare.quant.Kevin.quant_room.IndexActiveStyleAnalyse import EquityIndexStyleCalculator
-from hbshare.quant.Kevin.convertible_bond.CBMarketIV import CBMarketIV, CBMarketPrice
+from hbshare.quant.Kevin.convertible_bond.CBMarketIV import CBMarketIV, CBMarketPrice, OptionIV
 from hbshare.quant.Kevin.asset_allocation.macro_index.stock_share_price_index_futures import StockSharePriceIndex
 from hbshare.quant.Kevin.asset_allocation.macro_index.stock_concept import StockConception
 
@@ -91,11 +91,12 @@ def update_daily(start_date, end_date):
     # 可转债市场隐含波动率
     CBMarketIV(start_date.replace('-', ''), end_date.replace('-', '')).get_construct_result()
     CBMarketPrice(start_date.replace('-', ''), end_date.replace('-', '')).get_construct_result()
+    OptionIV(start_date.replace('-', ''), end_date.replace('-', '')).get_construct_result()
     # 基差数据
     StockSharePriceIndex(start_date, end_date).get_construct_result()
 
 
 if __name__ == '__main__':
-    update_daily(start_date='2022-04-08', end_date='2022-04-08')
-    # update_monthly('2022-03-10', '2022-03-31')
-    # update_weekly(start_date='2021-09-01', end_date='2022-03-31')
+    update_daily(start_date='2022-07-25', end_date='2022-07-25')
+    # update_monthly('2022-06-10', '2022-06-30')
+    # update_weekly(start_date='2021-09-01', end_date='2022-06-30')
