@@ -1,11 +1,12 @@
 """
 Wind计算的转债的隐含波动率
 """
+import numpy as np
 from hbshare.fe.common.util.data_loader import get_trading_day_list
 from hbshare.quant.Kevin.asset_allocation.macro_index.util import create_table, delete_duplicate_records, WriteToDB
 import pandas as pd
 from tqdm import tqdm
-from datetime import datetime
+from datetime import datetime, timedelta
 import hbshare as hbs
 from WindPy import w
 
@@ -156,6 +157,97 @@ class CBMarketPrice:
             WriteToDB().write_to_db(data, self.table_name)
 
 
+class OptionIV:
+    def __init__(self, start_date, end_date, rolling_window=20, is_increment=1):
+        self.start_date = start_date
+        self.end_date = end_date
+        self.rolling_window = rolling_window
+        self.is_increment = is_increment
+        self.table_name = "etf_market_iv"
+        self._load_data()
+
+    def _load_data(self):
+        # IV
+        res = w.wsd("SH_5100501MIV.WI,SH_5103001MIV.WI,SZ_1599191MIV.WI,CFE_0003001MIV.WI", "close",
+                    self.start_date, self.end_date, "")
+        if res.ErrorCode != 0:
+            data = pd.DataFrame()
+            print("fetch implied volatility data error: start_date = {}, end_date = {}".format(
+                self.start_date, self.end_date))
+        elif len(res.Data) == 1:
+            date_list = [datetime.strftime(x, '%Y%m%d') for x in res.Times]
+            data = pd.DataFrame(res.Data[0], index=res.Codes, columns=date_list).T.sort_index()
+        else:
+            date_list = [datetime.strftime(x, '%Y%m%d') for x in res.Times]
+            data = pd.DataFrame(res.Data, index=res.Codes, columns=date_list).T.sort_index()
+
+        data['trade_date'] = data.index
+        data = data.reset_index(drop=True)
+        iv_df = data
+        iv_df.columns = [x.split('.')[0] for x in iv_df.columns]
+        # HV
+        start_dt = datetime.strptime(self.start_date, '%Y%m%d')
+        pre_date = (start_dt - timedelta(days=150)).strftime('%Y%m%d')
+        res = w.wsd("510050.SH,510300.SH,159919.SZ,000300.SH", "close", pre_date, self.end_date, "")
+        if res.ErrorCode != 0:
+            data = pd.DataFrame()
+            print("fetch close data error: start_date = {}, end_date = {}".format(pre_date, self.end_date))
+        elif len(res.Data) == 1:
+            date_list = [datetime.strftime(x, '%Y%m%d') for x in res.Times]
+            data = pd.DataFrame(res.Data[0], index=res.Codes, columns=date_list).T.sort_index()
+        else:
+            date_list = [datetime.strftime(x, '%Y%m%d') for x in res.Times]
+            data = pd.DataFrame(res.Data, index=res.Codes, columns=date_list).T.sort_index()
+
+        return_df = data.pct_change().dropna()
+        hv_df = return_df.rolling(self.rolling_window).std().loc[self.start_date:].dropna() * np.sqrt(252)
+        hv_df.columns = [x.replace('.', '_') for x in hv_df.columns]
+        hv_df['trade_date'] = hv_df.index
+        hv_df = hv_df.reset_index(drop=True)
+
+        index_df = data.loc[self.start_date:]
+        index_df.columns = [x.split('.')[0] + '_ix' for x in index_df.columns]
+        index_df['trade_date'] = index_df.index
+        index_df = index_df.reset_index(drop=True)
+
+        assert (iv_df.shape == hv_df.shape)
+        assert (iv_df.shape == index_df.shape)
+
+        self.data = iv_df.merge(hv_df, on='trade_date').merge(index_df, on='trade_date')
+
+    def get_construct_result(self):
+        if self.is_increment == 1:
+            data = self.data
+            sql_script = "delete from {} where trade_date >= {} and trade_date <= {}".format(
+                self.table_name, self.start_date, self.end_date)
+            # delete first
+            delete_duplicate_records(sql_script)
+            # add new records
+            WriteToDB().write_to_db(data, self.table_name)
+        else:
+            sql_script = """
+                create table etf_market_iv(
+                id int auto_increment primary key,
+                trade_date date not null,
+                SH_5100501MIV decimal(5, 4),
+                SH_5103001MIV decimal(5, 4),
+                SZ_1599191MIV decimal(5, 4),
+                CFE_0003001MIV decimal(5, 4),
+                510050_SH decimal(5, 4),
+                510300_SH decimal(5, 4),
+                159919_SZ decimal(5, 4),
+                000300_SH decimal(5, 4),
+                510050_ix decimal(8, 4),
+                510300_ix decimal(8, 4),
+                159919_ix decimal(8, 4),
+                000300_ix decimal(8, 4)) 
+            """
+            create_table(self.table_name, sql_script)
+            data = self.data
+            WriteToDB().write_to_db(data, self.table_name)
+
+
 if __name__ == '__main__':
     # CBMarketIV('20180101', '20201231').get_construct_result()
-    CBMarketPrice('20190101', '20191231', is_increment=1).get_construct_result()
+    # CBMarketPrice('20190101', '20191231', is_increment=1).get_construct_result()
+    OptionIV('20220614', '20220614', is_increment=1).get_construct_result()
\ No newline at end of file
