@@ -25,13 +25,14 @@ class FundNavAnalysor:
 
     def _load_data(self):
         trading_day_list = get_trading_day_list(self.start_date, self.end_date, frequency="week")
+        # nav_series = self.nav_series.copy()
         nav_series = self.nav_series.reindex(trading_day_list).dropna()
         # nav_series = self.nav_series.reindex(trading_day_list).fillna(method='ffill').dropna()
         # benchmark
         sql_script = "SELECT JYRQ as TRADEDATE, ZQMC as INDEXNAME, SPJG as TCLOSE from funddb.ZSJY WHERE ZQDM = '{}' " \
                      "and JYRQ >= {} and JYRQ <= {}".format(self.benchmark_id, self.start_date, self.end_date)
         res = hbs.db_data_query('readonly', sql_script, page_size=5000)
-        map_dict = {"000905": "中证500", "000300": "沪深300", "000852": "中证1000"}
+        map_dict = {"000905": "中证500", "000300": "沪深300", "000852": "中证1000", "881001": "万得全A"}
         benchmark_name = map_dict[self.benchmark_id]
         data = pd.DataFrame(res['data']).rename(columns={"TCLOSE": benchmark_name}).set_index(
             'TRADEDATE')[[benchmark_name]]
@@ -149,16 +150,21 @@ class FundNavAnalysor:
 
 
 if __name__ == '__main__':
-    # nv_series = get_fund_nav_from_sql('20211231', '20220311', {"白鹭精选量化鲲鹏十号": "SQB109"})
+    nv_series = get_fund_nav_from_sql('20211231', '20220311', {"白鹭精选量化鲲鹏十号": "SQB109"})
     # nv_series = pd.read_excel("C:\\Users\\kai.zhang\\Desktop\\FACTSHEET 基准比较 - 副本.xlsx", sheet_name=0, index_col=0)
     # nv_series['trade_date'] = nv_series.index
     # nv_series['trade_date'] = nv_series['trade_date'].apply(lambda x: datetime.strftime(x, '%Y%m%d'))
     # nv_series = nv_series.set_index('trade_date')['量派睿核十号']
-    #
 
-    # nv_series = pd.read_excel('D:\\平行公理拼接净值.xlsx', sheet_name=2)
+    # nv_series = pd.read_excel('D:\\研究基地\\D-量价类\\翰荣\\翰荣指数增强策略净值分析2022.04.08.xlsx', sheet_name=0, header=1)
     # nv_series['日期'] = nv_series['日期'].apply(lambda x: datetime.strftime(x, '%Y%m%d'))
-    # nv_series = nv_series.set_index('日期')['拼接净值']
+    # nv_series = nv_series.set_index('日期')['策略净值']
+
+    # nv_series = pd.read_excel("D:\\研究基地\\B-套利类\\展弘\\量化套利一号\\量化套利1号修正图.xlsx", sheet_name=0, index_col=0)
+    # nv_series['trade_date'] = nv_series.index
+    # nv_series['trade_date'] = nv_series['trade_date'].apply(lambda x: datetime.strftime(x, '%Y%m%d'))
+    # nv_series.rename(columns={"修正净值": "量化套利1号-修正"}, inplace=True)
+    # nv_series = nv_series.set_index('trade_date')['量化套利1号-修正'].dropna()
 
     # nv_series1 = get_fund_nav_from_sql('20200306', '20211231', {"白鹭alpha": "SJM897"})
     # return_series1 = nv_series1.pct_change().fillna(0.)
@@ -167,13 +173,24 @@ if __name__ == '__main__':
     # return_series = pd.concat([return_series1, return_series2], axis=0).sort_index()
     # nv_series = (1 + return_series).cumprod()
 
-    nv_series = get_fund_nav_from_sql('20220114', '20220325', {"伯兄永康": "STQ128"})
-
-    FundNavAnalysor('20220114', '20220325', '000852', nv_series).run()
     # nv_series = pd.read_excel(
     #     "D:\\研究基地\\L-From_路遥\\1-跟踪代销\\天演\\净值文件\\天演资本代表产品净值20220106.xlsx", sheet_name="300指增", header=1, index_col=0)
     # nv_series['trade_date'] = nv_series.index
     # nv_series['trade_date'] = nv_series['trade_date'].apply(lambda x: datetime.strftime(x, '%Y%m%d'))
     # nv_series.rename(columns={"复权净值": "天演300指增"}, inplace=True)
     # nv_series = nv_series.set_index('trade_date')['天演300指增']
-    # FundNavAnalysor('20191231', '20211231', '000300', nv_series).run()
\ No newline at end of file
+    # FundNavAnalysor('20191231', '20211231', '000300', nv_series).run()
+
+    # nv_series = get_fund_nav_from_sql('20210420', '20220429', {"白鹭精选量化鲲鹏十号": "SQB109"})
+    # nv_series = get_fund_nav_from_sql('20210420', '20220429', {"伯兄建康": "SQT564"})
+    # nv_series = get_fund_nav_from_sql('20200424', '20220325', {"泰铼联泰1号": "SJH121"})
+
+    # 启林1000指增
+    # nv_series1 = get_fund_nav_from_sql('20201023', '20211008', {"启林1000指增": "SJT863"})
+    # nv_series2 = get_fund_nav_from_sql('20211008', '20220513', {"启林1000指增": "SSU078"})
+    # nv_series2 = nv_series2 * nv_series1.loc['20211008']
+    # nv_series = pd.concat([nv_series1, nv_series2[1:]])
+
+    nv_series = get_fund_nav_from_sql('20201231', '20220715', {"凡二英火5号": "SJM016"})
+
+    FundNavAnalysor('20201231', '20220715', '000905', nv_series).run()
\ No newline at end of file
