@@ -76,6 +76,13 @@ class Neutral2Long:
 
         return df[[self.fund_name]]
 
+# 概率一号 vs 概率高频一号
+# from hbshare.quant.Kevin.quant_room.MyUtil.data_loader import get_fund_nav_from_sql
+# nav_series1 = get_fund_nav_from_sql('20211231', '20220422', {"概率一号": "SNM976"})
+# alpha_series1 = Neutral2Long(nav_series1['概率一号'], "概率一号", 0.8).get_construct_result()
+# nav_series2 = get_fund_nav_from_sql('20211231', '20220422', {"概率高频一号": "SNM980"})
+# alpha_series2 = Neutral2Long(nav_series2['概率高频一号'], "概率高频一号", 0.8).get_construct_result()
+
 # from hbshare.quant.Kevin.quant_room.MyUtil.data_loader import get_fund_nav_from_sql
 # nav_series = get_fund_nav_from_sql('20201220', '20220311', {"明汯中性一号": "ST7452"})
 # a = Neutral2Long(nav_series['明汯中性一号'], "明汯中性1号", 0.8).get_construct_result()
@@ -121,23 +128,73 @@ class Neutral2Long:
 # return_series = pd.concat([return_series1, return_series2], axis=0).sort_index()
 # local_nav = (1 + return_series).cumprod()
 
+# 希格斯： 回测 + 实盘
+# data1 = pd.read_excel('D:\\希格斯投资Alpha系列-实盘&回测超额表现20220415.xlsx', sheet_name=5)
+# data1['日期'] = data1['日期'].apply(lambda x: datetime.strftime(x, '%Y%m%d'))
+# data1 = data1.set_index('日期')['相对500每日超额']
+# data1 = data1[data1.index < '20210819']
+# data2 = pd.read_excel('D:\\希格斯投资Alpha系列-实盘&回测超额表现20220415.xlsx', sheet_name=4)
+# data2['日期'] = data2['日期'].apply(lambda x: datetime.strftime(x, '%Y%m%d'))
+# data2['相对500每日超额'] = np.where(
+#     data2['水手2号相对500每日超额'].isnull(), data2['水手3号相对500每日超额'], data2['水手2号相对500每日超额']) / 100.
+# data2 = data2.set_index('日期')['相对500每日超额']
+# data2 = data2[data2.index >= '20210819']
+# excess_series = pd.concat([data1, data2])
+#
+# trading_day_list = get_trading_day_list('20180214', '20220415')
+# benchmark_id = '000905'
+# sql_script = "SELECT JYRQ as TRADEDATE, ZQMC as INDEXNAME, SPJG as TCLOSE from funddb.ZSJY WHERE ZQDM = '{}' " \
+#              "and JYRQ >= {} and JYRQ <= {}".format(benchmark_id, '20180214', '20220415')
+# res = hbs.db_data_query('readonly', sql_script, page_size=2000)
+# data = pd.DataFrame(res['data']).rename(columns={"TCLOSE": "benchmark"}).set_index('TRADEDATE')[['benchmark']]
+# data = data.reindex(trading_day_list)
+# data = data.pct_change().dropna()['benchmark']
+# excess_series = excess_series.reindex(data.index)
+# return_series = excess_series + data
+# trading_day_list = get_trading_day_list('20180214', '20220415', frequency='week')
+# local_nav = (1 + return_series).cumprod().reindex(trading_day_list).to_frame('希格斯水手2号')
+
+
 # 伯兄建康
+# from hbshare.quant.Kevin.quant_room.MyUtil.data_loader import get_fund_nav_from_sql
+# local_nav = get_fund_nav_from_sql('20210730', '20220325', {"伯兄建康": "SQT564"})
+
+# nv_series = pd.read_excel('D:\\研究基地\\D-量价类\\翰荣\\翰荣指数增强策略净值分析2022.04.08.xlsx', sheet_name=0, header=1)
+# nv_series['日期'] = nv_series['日期'].apply(lambda x: datetime.strftime(x, '%Y%m%d'))
+# nv_series.rename(columns={"策略净值": "翰荣500指增"}, inplace=True)
+# local_nav = nv_series.set_index('日期')['翰荣500指增']
+
+# from hbshare.quant.Kevin.quant_room.MyUtil.data_loader import get_fund_nav_from_sql
+# local_nav = get_fund_nav_from_sql('20210305', '20220415', {"星阔广厦": "SNU706"})
+
 from hbshare.quant.Kevin.quant_room.MyUtil.data_loader import get_fund_nav_from_sql
-local_nav = get_fund_nav_from_sql('20210730', '20220325', {"伯兄建康": "SQT564"})
+local_nav = get_fund_nav_from_sql('20200710', '20220624', {"罗维盈安": "SLB914"})
 
-
-compare_dict = {"衍复指增三号": "SJH866",
-                "启林500指增": "SGY379",
-                "因诺聚配500指增": "SGX346",
-                "天演中证500指增": "P20830",
-                "诚奇中证500增强": "SLS817",
-                "明汯价值成长1期": "SS5789",
+compare_dict = {"衍复": "SJH866",
+                "启林": "SGY379",
+                "因诺": "SGX346",
+                "天演": "P20830",
+                "诚奇": "SLS817",
+                "明汯": "SS5789",
                 # "灵均进取1号": "SW3470",
-                "凡二英火5号": "SJM016",
-                "星阔广厦1号": "SNU706",
-                "世纪前沿500指增": "SGP682",
-                "赫富500指增一号": "SEP463",
-                "九坤日享500指增": "ST9804"}
+                "凡二": "SJM016",
+                "星阔": "SNU706",
+                "世纪前沿": "SGP682",
+                "赫富": "SEP463",
+                "九坤": "ST9804",
+                "乾象": "P48470",
+                "白鹭": "SQB109",
+                #
+                # "衍合500指数增强1号": "SLG867",
+                "朋锦永宁": "SGN254",
+                # "弈倍虎鲸": "SY0096"
+                }
+
+
+# compare_dict = {"YF": "SJM688",
+#                 "MH": "SGG585",
+#                 "JK": "SCP381",
+#                 "YN": "SGY044"}
 
 
 class LocalNavComparer:
@@ -165,6 +222,9 @@ class LocalNavComparer:
         nav_df = pd.merge(nav_df, local_nav, left_index=True, right_index=True, how='left').fillna(
             method='ffill', limit=1)
         nav_df = nav_df / nav_df.iloc[0]
+
+        nav_df = nav_df.dropna(axis=1)
+
         # benchmark
         benchmark_id = '000905'
         sql_script = "SELECT JYRQ as TRADEDATE, ZQMC as INDEXNAME, SPJG as TCLOSE from funddb.ZSJY WHERE ZQDM = '{}' " \
@@ -254,4 +314,4 @@ class LocalNavComparer:
 
 
 if __name__ == '__main__':
-    LocalNavComparer("20210730", "20220325").get_construct_result()
\ No newline at end of file
+    LocalNavComparer("20200710", "20220624").get_construct_result()
\ No newline at end of file
