@@ -10,9 +10,10 @@ from hbshare.quant.Kevin.rm_associated.config import engine_params
 from hbshare.fe.common.util.config import factor_map_dict
 import plotly
 import plotly.graph_objs as go
+import plotly.figure_factory as ff
 
 
-def plot_render(plot_dic, width=1200, height=800, **kwargs):
+def plot_render(plot_dic, width=1000, height=600, **kwargs):
     kwargs['output_type'] = 'div'
     plot_str = plotly.offline.plot(plot_dic, **kwargs)
     print('%%angular <div style="height: %ipx; width: %spx"> %s </div>' % (height, width, plot_str))
@@ -49,6 +50,7 @@ class HoldingAnalysor:
         engine = create_engine(engine_params)
         holding_df = pd.read_sql(sql_script, engine)
         holding_df['trade_date'] = holding_df['trade_date'].apply(lambda x: datetime.datetime.strftime(x, '%Y%m%d'))
+        # holding_df['weight'] /= holding_df['weight'].sum()
 
         return holding_df.set_index('ticker')['weight'] / 100.
 
@@ -127,7 +129,7 @@ class HoldingAnalysor:
         }
 
     @staticmethod
-    def plotly_style_bar(df, title_text, figsize=(1200, 800), legend_x=0.30):
+    def plotly_style_bar(df, title_text, figsize=(1000, 600), legend_x=0.30):
         fig_width, fig_height = figsize
         cols = df.columns.tolist()
         color_list = ['rgb(49, 130, 189)', 'rgb(204, 204, 204)', 'rgb(216, 0, 18)']
@@ -200,20 +202,47 @@ class HoldingAnalysor:
 
         return data, layout
 
+    @staticmethod
+    def plotly_displot(df, title_text, figsize=(800, 600)):
+        fig_width, fig_height = figsize
+        group_labels = ['个股权重', '个股权重偏离']
+        fig = ff.create_distplot([df[df['个股权重'] > 1e-8]['个股权重'], df['个股权重偏离']],
+                                 group_labels,
+                                 show_hist=False,
+                                 show_rug=False)
+        fig.update_layout(title=title_text,
+                          xaxis_title='权重（%）',
+                          yaxis_title='density',
+                          width=fig_width, height=fig_height,
+                          template="plotly_white",
+                          showlegend=True,
+                          legend=dict(
+                              orientation="v",
+                              y=1,
+                              yanchor="top",
+                              x=1.0,
+                              xanchor="right")
+                          )
+
+        return fig.data, fig.layout
+
     def get_construct_result(self, isPlot=True):
         portfolio_weight_series = self.data_param.get('portfolio_weight_series')
-        benchmark_weight_series = self.data_param.get('benchmark_weight_series')
+        benchmark_weight_series = self.data_param.get('benchmark_weight_series') * portfolio_weight_series.sum()
         benchmark_components = self.data_param.get('benchmark_components')
         style_exposure_df = self.data_param.get('style_exposure_df')
         concept_df = self.data_param.get('concept_df')
 
         # 板块分布
-        weight_df = portfolio_weight_series.reset_index()
+        weight_df = portfolio_weight_series.reset_index().rename(columns={"weight": "port"}).merge(
+            benchmark_weight_series.reset_index().rename(columns={"consTickerSymbol": "ticker", "weight": "bm"}),
+            on='ticker', how='outer').fillna(0.)
         weight_df.loc[weight_df['ticker'].str.startswith('0'), 'sector'] = '深市'
         weight_df.loc[weight_df['ticker'].str.startswith('60'), 'sector'] = '沪市'
         weight_df.loc[weight_df['ticker'].str.startswith('30'), 'sector'] = '创业板'
         weight_df.loc[weight_df['ticker'].str.startswith('688'), 'sector'] = '科创板'
-        sector_distribution = weight_df.groupby('sector')['weight'].sum()
+        sector_distribution = weight_df.groupby('sector')[['port', 'bm']].sum().reset_index().set_index('sector')
+        sector_distribution['active'] = sector_distribution['port'] - sector_distribution['bm']
 
         # 成分股分布
         w_df = pd.merge(portfolio_weight_series.reset_index(), benchmark_components, on='ticker', how='left')
@@ -221,6 +250,7 @@ class HoldingAnalysor:
         bm_distribution = w_df.groupby('benchmark_id')['weight'].sum().reset_index().replace(
             {"000300": "沪深300", "000905": "中证500", "000852": "中证1000", "other": "1800以外"}).set_index('benchmark_id')
         bm_distribution = bm_distribution['weight']
+        bm_distribution.loc['非权益资产'] = 1 - bm_distribution.sum()
 
         # 风格及行业分布
         idx = portfolio_weight_series.index.union(benchmark_weight_series.index).intersection(
@@ -239,7 +269,7 @@ class HoldingAnalysor:
 
         # 概念
         portfolio_weight_series = self.data_param.get('portfolio_weight_series')
-        benchmark_weight_series = self.data_param.get('benchmark_weight_series')
+        benchmark_weight_series = self.data_param.get('benchmark_weight_series') * portfolio_weight_series.sum()
         concept_df = concept_df.join(pd.get_dummies(concept_df['concept']))
         concept_series = concept_df.groupby('ticker')[concept_df.columns[-8:]].sum()
         idx = portfolio_weight_series.index.union(benchmark_weight_series.index).intersection(
@@ -252,6 +282,13 @@ class HoldingAnalysor:
         concept_expo = pd.concat([portfolio_concept.to_frame('port'), benchmark_concept.to_frame('bm')], axis=1)
         concept_expo['active'] = concept_expo['port'] - concept_expo['bm']
 
+        # 个股权重及权重偏离度
+        portfolio_weight_series = self.data_param.get('portfolio_weight_series')
+        benchmark_weight_series = self.data_param.get('benchmark_weight_series') * portfolio_weight_series.sum()
+        weight_df = portfolio_weight_series.to_frame('port').merge(
+            benchmark_weight_series.to_frame('bm'), left_index=True, right_index=True, how='outer').fillna(0.)
+        weight_df['active'] = (weight_df['port'] - weight_df['bm']).abs()
+
         # 风格
         style_df = style_expo[['port', 'bm', 'active']].rename(
             columns={"port": self.fund_name, "bm": benchmark_id_map[self.benchmark_id], "active": "主动暴露"}).loc[
@@ -265,15 +302,15 @@ class HoldingAnalysor:
             columns={"port": self.fund_name, "bm": benchmark_id_map[self.benchmark_id], "active": "主动暴露"}).iloc[10:]
         ind_df.index = [reverse_ind[x] for x in ind_df.index]
         if isPlot:
-            data, layout = self.plotly_style_bar(ind_df, "横截面持仓行业暴露", figsize=(1500, 700), legend_x=0.35)
-            plot_render({"data": data, "layout": layout}, width=1500, height=700)
+            data, layout = self.plotly_style_bar(ind_df, "横截面持仓行业暴露", figsize=(1500, 600), legend_x=0.35)
+            plot_render({"data": data, "layout": layout}, width=1500, height=600)
         # 板块分布
-        sector_distribution.loc['非权益资产'] = 1 - sector_distribution.sum()
+        sector_distribution = sector_distribution.rename(
+            columns={"port": self.fund_name, "bm": benchmark_id_map[self.benchmark_id], "active": "相对暴露"})
         if isPlot:
-            data, layout = self.plotly_pie(sector_distribution, "持仓板块分布", figsize=(800, 600))
-            plot_render({"data": data, "layout": layout}, width=800, height=600)
+            data, layout = self.plotly_style_bar(sector_distribution, "横截面持仓板块暴露")
+            plot_render({"data": data, "layout": layout})
         # 成分股分布
-        bm_distribution.loc['非权益资产'] = 1 - bm_distribution.sum()
         if isPlot:
             data, layout = self.plotly_pie(bm_distribution, "持仓指数成分分布", figsize=(800, 600))
             plot_render({"data": data, "layout": layout}, width=800, height=600)
@@ -283,10 +320,16 @@ class HoldingAnalysor:
         if isPlot:
             data, layout = self.plotly_style_bar(cp_dis_df, "横截面概念持仓暴露")
             plot_render({"data": data, "layout": layout})
+        # 个股权重偏离
+        weight_df = weight_df.rename(columns={"port": "个股权重", "active": "个股权重偏离"}) * 100
+        if isPlot:
+            data, layout = self.plotly_displot(weight_df, "个股权重及偏离度分布, 持股数量: {}只".format(
+                self.data_param.get('portfolio_weight_series').shape[0]))
+            plot_render({"data": data, "layout": layout})
 
         results = {"style_df": style_df, "ind_df": ind_df,
                    "sector_distribution": sector_distribution, "bm_distribution": bm_distribution,
-                   "concept_df": cp_dis_df}
+                   "concept_df": cp_dis_df, "weight_df": weight_df}
 
         return results
 
@@ -304,6 +347,10 @@ class HoldingDistribution:
         engine = create_engine(engine_params)
         holding_df = pd.read_sql(sql_script, engine)
         holding_df['trade_date'] = holding_df['trade_date'].apply(lambda x: datetime.datetime.strftime(x, '%Y%m%d'))
+        # 归一化
+        # holding_df['weight_sum'] = holding_df.groupby('trade_date')['weight'].transform('sum')
+        # holding_df['weight'] /= holding_df['weight_sum']
+
         holding_df['weight'] /= 100.
 
         return holding_df[['trade_date', 'ticker', 'weight']]
@@ -378,7 +425,10 @@ class HoldingDistribution:
 if __name__ == '__main__':
     # d_list = ['20201231', '20210131', '20210228']
     # tmp = HoldingAnalysor("星阔广厦1号中证500指数增强", "20220128", "000905").get_construct_result(isPlot=False)
-    tmp = HoldingAnalysor("星阔广厦1号中证500指数增强", "20210730", "000905").get_construct_result(isPlot=True)
-    # print(tmp['style_df'])
-    # dis_df = HoldingDistribution('20210310', '20211118', '因诺聚配中证500指数增强').get_construct_result()
+
+    hd_analysor = HoldingAnalysor("量锐62号", "20220531", "000905")
+
+    tmp = HoldingAnalysor("量锐62号", "20220531", "000905").get_construct_result(isPlot=False)
+    print(tmp['style_df'])
+    # dis_df = HoldingDistribution('20210310', '20220602', '因诺聚配中证500指数增强').get_construct_result()
     # print(dis_df)
\ No newline at end of file
