@@ -33,8 +33,8 @@ class QuarterAssetAllocationReport:
         df = df[(df['month'] != df['next_month']) & (df['t_date'] >= self.start_date)]
         trading_day_list = sorted(df['t_date'].tolist())
 
-        # from hbshare.quant.Kevin.quant_room.MyUtil.data_loader import get_trading_day_list
-        # trading_day_list = get_trading_day_list(self.start_date, self.end_date, frequency="week")
+        from hbshare.quant.Kevin.quant_room.MyUtil.data_loader import get_trading_day_list
+        trading_day_list = get_trading_day_list(self.start_date, self.end_date, frequency="week")
 
         # type
         data_param = dict()
@@ -186,8 +186,11 @@ def plotly_line(df, day_list, title_text, save_path):
 
 if __name__ == '__main__':
     allo_rep = QuarterAssetAllocationReport(
-        start_date='20210320', end_date='20220325',
-        data_path='D:\\量化产品跟踪\\指数增强', file_name='指增-20220325.xlsx')
+        start_date='20191228', end_date='20220715',
+        data_path='D:\\量化产品跟踪\\指数增强', file_name='指增-20220715.xlsx')
+    # allo_rep = QuarterAssetAllocationReport(
+    #     start_date='20161230', end_date='20220527',
+    #     data_path='D:\\量化产品跟踪\\指数增强', file_name='指增-20220527.xlsx')
 
     excess_df, excess_df2 = allo_rep.calculate_excess_return()
 
